@@ -34,15 +34,11 @@
 #include "cairo-dock-log.h"
 #include "cairo-dock-gui-factory.h"
 #include "cairo-dock-keyfile-utilities.h"
-#include "cairo-dock-animations.h"
 #include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-dock-factory.h"
 #include "cairo-dock-launcher-factory.h"
-#include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-file-manager.h"
 #include "cairo-dock-applications-manager.h"
-#include "cairo-dock-keybinder.h"
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-gui-manager.h"
 #include "cairo-dock-gui-commons.h"
@@ -73,7 +69,6 @@ extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gchar *g_cConfFile;
 extern CairoContainer *g_pPrimaryContainer;
 extern CairoDock *g_pMainDock;
-extern gchar *g_cCurrentLaunchersPath;
 extern gchar *g_cCairoDockDataDir;
 extern gboolean g_bEasterEggs;
 
@@ -104,8 +99,6 @@ struct _CairoDockGroupDescription {
 	} ;
 
 static CairoDockCategoryWidgetTable s_pCategoryWidgetTables[CAIRO_DOCK_NB_CATEGORY+1];
-GSList *s_pCurrentWidgetList;  // liste des widgets du module courant.
-GSList *s_pExtraCurrentWidgetList;  // liste des widgets des eventuels modules lies.
 static GList *s_pGroupDescriptionList = NULL;
 static GtkWidget *s_pPreviewBox = NULL;
 static GtkWidget *s_pPreviewImage = NULL;
@@ -1036,16 +1029,18 @@ static gboolean on_leave_group_button (GtkButton *button, GdkEventCrossing *pEve
 	// check that we are really outside of the button (this may be false if the dialog is appearing under the mouse and has not yet its input shape (X lag)).
 	if (pEvent->detail != GDK_NOTIFY_ANCESTOR)  // a LeaveNotify event not within the same window (ie, either an Alt+Tab or the dialog that spawned under the cursor)
 	{
+		GtkAllocation allocation;
+		gtk_widget_get_allocation (GTK_WIDGET (button), &allocation);
 		int x, y;
 		#if GTK_CHECK_VERSION (3, 4, 0)
 		GdkDevice *pDevice = gdk_device_manager_get_client_pointer (
 			gdk_display_get_device_manager (gtk_widget_get_display (GTK_WIDGET (button))));
 		gdk_window_get_device_position (gtk_widget_get_window (GTK_WIDGET (button)), pDevice, &x, &y, NULL);
+		x -= allocation.x;
+		y -= allocation.y;
 		#else
 		gtk_widget_get_pointer (GTK_WIDGET (button), &x, &y);
 		#endif
-		GtkAllocation allocation;
-		gtk_widget_get_allocation (GTK_WIDGET (button), &allocation);
 		if (x >= 0 && x < allocation.width && y >= 0 && y < allocation.height)  // we are actually still inside the button, ignore the event, we'll get an 'enter' event as soon as the dialog's input shape is ready.
 		{
 			s_iSidCheckGroupButton = g_timeout_add (1000, _check_group_button, NULL);  // check in a moment if we left the button because of the dialog or because of another window (alt+tab).
@@ -1666,16 +1661,16 @@ static GtkWidget *cairo_dock_build_main_ihm (const gchar *cConfFilePath)  // 'cC
 	GtkWidget *pMainHBox = _gtk_hbox_new (0);
 	gtk_container_add (GTK_CONTAINER (s_pMainWindow), pMainHBox);
 	
-	if (g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] > CAIRO_DOCK_CONF_PANEL_WIDTH)
+	if (gldi_get_desktop_width() > CAIRO_DOCK_CONF_PANEL_WIDTH)
 	{
 		s_iPreviewWidth = CAIRO_DOCK_PREVIEW_WIDTH;
 		s_iNbButtonsByRow = CAIRO_DOCK_NB_BUTTONS_BY_ROW;
 	}
-	else if (g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] > CAIRO_DOCK_CONF_PANEL_WIDTH_MIN)
+	else if (gldi_get_desktop_width() > CAIRO_DOCK_CONF_PANEL_WIDTH_MIN)
 	{
 		double a = 1.*(CAIRO_DOCK_PREVIEW_WIDTH - CAIRO_DOCK_PREVIEW_WIDTH_MIN) / (CAIRO_DOCK_CONF_PANEL_WIDTH - CAIRO_DOCK_CONF_PANEL_WIDTH_MIN);
 		double b = CAIRO_DOCK_PREVIEW_WIDTH_MIN - CAIRO_DOCK_CONF_PANEL_WIDTH_MIN * a;
-		s_iPreviewWidth = a * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] + b;
+		s_iPreviewWidth = a * gldi_get_desktop_width() + b;
 		s_iNbButtonsByRow = CAIRO_DOCK_NB_BUTTONS_BY_ROW - 1;
 	}
 	else
@@ -1979,8 +1974,8 @@ static GtkWidget *cairo_dock_build_main_ihm (const gchar *cConfFilePath)  // 'cC
 	g_object_set_data (G_OBJECT (s_pMainWindow), "frame-width", GINT_TO_POINTER (200));
 	
 	gtk_window_resize (GTK_WINDOW (s_pMainWindow),
-		MIN (CAIRO_DOCK_CONF_PANEL_WIDTH, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]),
-		MIN (CAIRO_DOCK_CONF_PANEL_HEIGHT, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
+		MIN (CAIRO_DOCK_CONF_PANEL_WIDTH, gldi_get_desktop_width()),
+		MIN (CAIRO_DOCK_CONF_PANEL_HEIGHT, gldi_get_desktop_height() - (g_pMainDock && g_pMainDock->container.bIsHorizontal ? g_pMainDock->iMaxDockHeight : 0)));
 	
 	
 	gtk_widget_show_all (s_pMainWindow);
@@ -2487,6 +2482,12 @@ static GtkWidget *show_gui (Icon *pIcon, CairoContainer *pContainer, CairoDockMo
 	return s_pMainWindow;
 }
 
+static GtkWidget *show_addons (void)
+{
+	cairo_dock_build_main_ihm (g_cConfFile);
+	return s_pMainWindow;
+}
+
 static void reload_items (void)
 {
 	if (s_pMainWindow == NULL)
@@ -2627,6 +2628,7 @@ void cairo_dock_register_advanced_gui_backend (void)
 	pBackend->update_modules_list 				= update_modules_list;
 	pBackend->update_shortkeys 					= update_shortkeys;
 	pBackend->show_gui 							= show_gui;
+	pBackend->show_addons 							= show_addons;
 	pBackend->reload_items 						= reload_items;
 	pBackend->reload 							= reload;
 	pBackend->cDisplayedName 					= _("Simple Mode");
