@@ -574,7 +574,7 @@ static void cairo_dock_add_main_dock (G_GNUC_UNUSED GtkMenuItem *pMenuItem, G_GN
 	
 	cairo_dock_gui_trigger_reload_items ();  // pas de signal "new_dock"
 	
-	g_timeout_add_seconds (1, (GSourceFunc)_show_new_dock_msg, g_strdup (cDockName));  // delai, car sa fenetre n'est pas encore bien placee (0,0).
+	g_timeout_add_seconds (1, (GSourceFunc)_show_new_dock_msg, cDockName);  // delai, car sa fenetre n'est pas encore bien placee (0,0).
 }
 
 static void cairo_dock_add_separator (G_GNUC_UNUSED GtkMenuItem *pMenuItem, gpointer *data)
@@ -713,25 +713,29 @@ static void _cairo_dock_move_launcher_to_dock (GtkMenuItem *pMenuItem, const gch
 	g_free (cValidDockName);
 }
 
-static void _add_one_dock_to_menu (const gchar *cName, CairoDock *pDock, GtkWidget *pMenu)
+static void _cairo_dock_add_docks_sub_menu (GtkWidget *pMenu, Icon *pIcon)
 {
-	// on ne prend que les sous-docks utilisateur.
-	Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, NULL);
-	if (pPointingIcon && ! CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pPointingIcon))
-		return;
-	// on elimine le dock courant.
-	Icon *pIcon = g_object_get_data (G_OBJECT (pMenu), "icon-item");
-	if (strcmp (pIcon->cParentDockName, cName) == 0)
-		return;
-	// on elimine le sous-dock.
-	if (pIcon->pSubDock != NULL && pIcon->pSubDock == pDock)
-		return;
-	// On definit un nom plus parlant.
-	gchar *cUserName = cairo_dock_get_readable_name_for_fock (pDock);
-	// on rajoute une entree pour le dock.
-	GtkWidget *pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (cUserName ? cUserName : cName, NULL, G_CALLBACK (_cairo_dock_move_launcher_to_dock), pMenu, (gpointer)cName);
+	GtkWidget *pSubMenuDocks = cairo_dock_create_sub_menu (_("Move to another dock"), pMenu, GTK_STOCK_JUMP_TO);
+	g_object_set_data (G_OBJECT (pSubMenuDocks), "icon-item", pIcon);
+	GtkWidget *pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("New main dock"), GTK_STOCK_NEW, G_CALLBACK (_cairo_dock_move_launcher_to_dock), pSubMenuDocks, NULL);
 	g_object_set_data (G_OBJECT (pMenuItem), "icon-item", pIcon);
-	g_free (cUserName);
+	
+	GList *pDocks = cairo_dock_get_available_docks_for_icon (pIcon);
+	const gchar *cName;
+	gchar *cUserName;
+	CairoDock *pDock;
+	GList *d;
+	for (d = pDocks; d != NULL; d = d->next)
+	{
+		pDock = d->data;
+		cName = cairo_dock_search_dock_name (pDock);
+		cUserName = cairo_dock_get_readable_name_for_fock (pDock);
+		
+		GtkWidget *pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (cUserName ? cUserName : cName, NULL, G_CALLBACK (_cairo_dock_move_launcher_to_dock), pSubMenuDocks, (gpointer)cName);
+		g_object_set_data (G_OBJECT (pMenuItem), "icon-item", pIcon);
+		g_free (cUserName);
+	}
+	g_list_free (pDocks);
 }
 
 static void _cairo_dock_make_launcher_from_appli (G_GNUC_UNUSED GtkMenuItem *pMenuItem, gpointer *data)
@@ -745,7 +749,7 @@ static void _cairo_dock_make_launcher_from_appli (G_GNUC_UNUSED GtkMenuItem *pMe
 	gchar *cDesktopFilePath = g_strdup (cairo_dock_get_class_desktop_file (icon->cClass));
 	if (cDesktopFilePath == NULL)
 	{
-		gchar *cCommand = g_strdup_printf ("locate /%s.desktop --limit=1 -i", icon->cClass);
+		gchar *cCommand = g_strdup_printf ("locate /usr/*/%s.desktop --limit=1 -i", icon->cClass);
 		gchar *cResult = cairo_dock_launch_command_sync (cCommand);
 		if (cResult != NULL && *cResult != '\0')
 		{
@@ -1200,11 +1204,7 @@ gboolean cairo_dock_notification_build_container_menu (G_GNUC_UNUSED gpointer *p
 				pMenuItem = _add_entry_in_menu (_("Remove"), GTK_STOCK_REMOVE, _cairo_dock_remove_launcher, pItemSubMenu);
 				gtk_widget_set_tooltip_text (pMenuItem, _("You can remove a launcher by dragging it out of the dock with the mouse ."));
 				
-				GtkWidget *pSubMenuDocks = cairo_dock_create_sub_menu (_("Move to another dock"), pItemSubMenu, GTK_STOCK_JUMP_TO);
-				g_object_set_data (G_OBJECT (pSubMenuDocks), "icon-item", pIcon);
-				pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("New main dock"), GTK_STOCK_NEW, G_CALLBACK (_cairo_dock_move_launcher_to_dock), pSubMenuDocks, NULL);
-				g_object_set_data (G_OBJECT (pMenuItem), "icon-item", pIcon);
-				cairo_dock_foreach_docks ((GHFunc) _add_one_dock_to_menu, pSubMenuDocks);
+				_cairo_dock_add_docks_sub_menu (pItemSubMenu, pIcon);
 			}
 			else if (CAIRO_DOCK_ICON_TYPE_IS_APPLI (pIcon)
 				|| CAIRO_DOCK_ICON_TYPE_IS_CLASS_CONTAINER (pIcon))  // appli with no launcher
@@ -1260,11 +1260,7 @@ gboolean cairo_dock_notification_build_container_menu (G_GNUC_UNUSED gpointer *p
 				
 				if (CAIRO_DOCK_IS_DOCK (pContainer) && pIcon->cParentDockName != NULL)  // sinon bien sur ca n'est pas la peine de presenter l'option (Cairo-Penguin par exemple)
 				{
-					GtkWidget *pSubMenuDocks = cairo_dock_create_sub_menu (_("Move to another dock"), pItemSubMenu, GTK_STOCK_JUMP_TO);
-					g_object_set_data (G_OBJECT (pSubMenuDocks), "icon-item", pIcon);
-					pMenuItem = cairo_dock_add_in_menu_with_stock_and_data (_("New main dock"), GTK_STOCK_NEW, G_CALLBACK (_cairo_dock_move_launcher_to_dock), pSubMenuDocks, NULL);
-					g_object_set_data (G_OBJECT (pMenuItem), "icon-item", pIcon);
-					cairo_dock_foreach_docks ((GHFunc) _add_one_dock_to_menu, pSubMenuDocks);
+					_cairo_dock_add_docks_sub_menu (pItemSubMenu, pIcon);
 				}
 				
 				pMenuItem = gtk_separator_menu_item_new ();
