@@ -33,6 +33,7 @@
 #include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-draw.h"
+#include "cairo-dock-themes-manager.h"
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-container.h"
 #include "cairo-dock-applications-manager.h"
@@ -419,13 +420,17 @@ static inline void _add_one_module (G_GNUC_UNUSED const gchar *cModuleName, Cair
 }
 static gboolean _add_one_module_to_model (const gchar *cModuleName, CairoDockModule *pModule, GtkTreeStore *model)
 {
-	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_BEHAVIOR && pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME && ! cairo_dock_module_is_auto_loaded (pModule) && pModule->pInstancesList != NULL)
+	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_BEHAVIOR && pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME && ! cairo_dock_module_is_auto_loaded (pModule))
 	{
-		CairoDockModuleInstance *pModuleInstance = pModule->pInstancesList->data;
-		if (pModuleInstance->pIcon == NULL || (pModuleInstance->pDock && !pModuleInstance->pIcon->cParentDockName))
+		GList *pItem;
+		for (pItem = pModule->pInstancesList; pItem != NULL; pItem = pItem->next)
 		{
-			// on ajoute une ligne pour l'applet.
-			_add_one_module (cModuleName, pModuleInstance, model);
+			CairoDockModuleInstance *pModuleInstance = pItem->data;
+			if (pModuleInstance->pIcon == NULL || (pModuleInstance->pDock && !pModuleInstance->pIcon->cParentDockName))
+			{
+				// on ajoute une ligne pour l'applet.
+				_add_one_module (cModuleName, pModuleInstance, model);
+			}
 		}
 	}
 	return FALSE; // FALSE => keep going
@@ -785,8 +790,8 @@ ItemsWidget *cairo_dock_items_widget_new (GtkWindow *pMainWindow)
 	gtk_paned_pack1 (GTK_PANED (pLauncherPane), pLauncherWindow, TRUE, FALSE);
 	
 	//\_____________ On essaie de definir une taille correcte.
-	int w = MIN (CAIRO_DOCK_LAUNCHER_PANEL_WIDTH, g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
-	if (g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] < CAIRO_DOCK_LAUNCHER_PANEL_WIDTH)  // ecran trop petit, on va essayer de reserver au moins R pixels pour le panneau de droite (avec un minimum de L pixels pour celui de gauche).
+	int w = MIN (CAIRO_DOCK_LAUNCHER_PANEL_WIDTH, gldi_get_desktop_width());
+	if (gldi_get_desktop_width() < CAIRO_DOCK_LAUNCHER_PANEL_WIDTH)  // ecran trop petit, on va essayer de reserver au moins R pixels pour le panneau de droite (avec un minimum de L pixels pour celui de gauche).
 		gtk_paned_set_position (GTK_PANED (pLauncherPane), MAX (CAIRO_DOCK_LEFT_PANE_MIN_WIDTH, w - CAIRO_DOCK_RIGHT_PANE_MIN_WIDTH));
 	else  // we set a default width rather than letting GTK guess the best, because the right panel is more important than the left one.
 		gtk_paned_set_position (GTK_PANED (pLauncherPane), CAIRO_DOCK_LEFT_PANE_DEFAULT_WIDTH);
@@ -839,7 +844,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 			pModuleInstance->pModule->pInterface->save_custom_widget (pModuleInstance, pKeyFile, pWidgetList);
 		
 		// write everything in the conf file.
-		cairo_dock_write_keys_to_file (pKeyFile, pModuleInstance->cConfFilePath);
+		cairo_dock_write_keys_to_conf_file (pKeyFile, pModuleInstance->cConfFilePath);
 		g_key_file_free (pKeyFile);
 		
 		// reload module.
@@ -863,7 +868,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 			cairo_dock_update_keyfile_from_widget_list (pKeyFile, pWidgetList);
 			
 			// write everything in the conf file.
-			cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
+			cairo_dock_write_keys_to_conf_file (pKeyFile, cConfFilePath);
 			g_key_file_free (pKeyFile);
 			g_free (cConfFilePath);
 			
@@ -897,7 +902,7 @@ static void _items_widget_apply (CDWidget *pCdWidget)
 		}
 		
 		// write everything in the conf file.
-		cairo_dock_write_keys_to_file (pKeyFile, cConfFilePath);
+		cairo_dock_write_keys_to_conf_file (pKeyFile, cConfFilePath);
 		g_key_file_free (pKeyFile);
 		g_free (cConfFilePath);
 		
