@@ -141,7 +141,7 @@ static void _cairo_dock_render_category (G_GNUC_UNUSED GtkTreeViewColumn *tree_c
 	{
 		case CAIRO_DOCK_CATEGORY_APPLET_FILES:
 			cCategory = _("Files");
-			g_object_set (cell, "foreground", "#004EA1", NULL);  // bleu
+			g_object_set (cell, "foreground", "#004EA1", NULL);  // blue
 			g_object_set (cell, "foreground-set", TRUE, NULL);
 		break;
 		case CAIRO_DOCK_CATEGORY_APPLET_INTERNET:
@@ -151,22 +151,27 @@ static void _cairo_dock_render_category (G_GNUC_UNUSED GtkTreeViewColumn *tree_c
 		break;
 		case CAIRO_DOCK_CATEGORY_APPLET_DESKTOP:
 			cCategory = _("Desktop");
-			g_object_set (cell, "foreground", "#116E08", NULL);  // vert
+			g_object_set (cell, "foreground", "#116E08", NULL);  // green
 			g_object_set (cell, "foreground-set", TRUE, NULL);
 		break;
 		case CAIRO_DOCK_CATEGORY_APPLET_ACCESSORY:
 			cCategory = _("Accessory");
-			g_object_set (cell, "foreground", "#900009", NULL);  // rouge
+			g_object_set (cell, "foreground", "#900009", NULL);  // red
 			g_object_set (cell, "foreground-set", TRUE, NULL);
 		break;
 		case CAIRO_DOCK_CATEGORY_APPLET_SYSTEM:
 			cCategory = _("System");
-			g_object_set (cell, "foreground", "#A58B0D", NULL);  // jaune
+			g_object_set (cell, "foreground", "#A58B0D", NULL);  // yellow
 			g_object_set (cell, "foreground-set", TRUE, NULL);
 		break;
 		case CAIRO_DOCK_CATEGORY_APPLET_FUN:
 			cCategory = _("Fun");
-			g_object_set (cell, "foreground", "#FF55FF", NULL);  // rose
+			g_object_set (cell, "foreground", "#FF55FF", NULL);  // purple
+			g_object_set (cell, "foreground-set", TRUE, NULL);
+		break;
+		case CAIRO_DOCK_CATEGORY_BEHAVIOR: // help applet
+			cCategory = _("Behaviour");
+			g_object_set (cell, "foreground", "#000066", NULL);  // dark blue
 			g_object_set (cell, "foreground-set", TRUE, NULL);
 		break;
 		default:
@@ -181,7 +186,8 @@ static void _cairo_dock_render_category (G_GNUC_UNUSED GtkTreeViewColumn *tree_c
 
 static gboolean _cairo_dock_add_module_to_modele (gchar *cModuleName, CairoDockModule *pModule, GtkListStore *pModel)
 {
-	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_BEHAVIOR && pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME && ! cairo_dock_module_is_auto_loaded (pModule))
+	if (pModule->pVisitCard->iCategory != CAIRO_DOCK_CATEGORY_THEME  // don't display the animations plug-ins
+		&& ! cairo_dock_module_is_auto_loaded (pModule))  // don't display modules that can't be disabled
 	{
 		//g_print (" + %s\n",  pModule->pVisitCard->cIconFilePath);
 		gchar *cIcon = cairo_dock_get_icon_for_gui (pModule->pVisitCard->cModuleName,
@@ -222,6 +228,7 @@ static GtkWidget *_cairo_dock_build_modules_treeview (void)
 	
 	//\______________ On remplit le modele avec les modules de la categorie.
 	GtkTreeModel *pModel = gtk_tree_view_get_model (GTK_TREE_VIEW (pOneWidget));
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (pModel), CAIRO_DOCK_MODEL_STATE, GTK_SORT_ASCENDING);
 	cairo_dock_foreach_module ((GHRFunc) _cairo_dock_add_module_to_modele, pModel);
 	
 	//\______________ On definit l'affichage du modele dans le tree-view.
@@ -261,7 +268,7 @@ static void _build_plugins_widget (PluginsWidget *pPluginsWidget)
 	//\_____________ On l'ajoute a la fenetre.
 	GtkWidget *pKeyBox = _gtk_hbox_new (CAIRO_DOCK_GUI_MARGIN);
 	GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
-	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - 210), NULL);
+	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, gldi_get_desktop_height() - 210), NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pPluginsWidget->pTreeView);
 	gtk_box_pack_start (GTK_BOX (pKeyBox), pScrolledWindow, TRUE, TRUE, 0);
@@ -271,7 +278,7 @@ static void _build_plugins_widget (PluginsWidget *pPluginsWidget)
 	gchar *cDefaultMessage = g_strdup_printf ("<b><span font_desc=\"Sans 14\">%s</span></b>", _("Click on an applet in order to have a preview and a description for it."));
 	GtkWidget *pPreviewBox = cairo_dock_gui_make_preview_box (pKeyBox, pPluginsWidget->pTreeView, FALSE, 1, cDefaultMessage, CAIRO_DOCK_SHARE_DATA_DIR"/images/"CAIRO_DOCK_LOGO, pDataGarbage);  // vertical packaging.
 	GtkWidget *pScrolledWindow2 = gtk_scrolled_window_new (NULL, NULL);
-	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - 210), NULL);
+	g_object_set (pScrolledWindow, "height-request", MIN (2*CAIRO_DOCK_PREVIEW_HEIGHT, gldi_get_desktop_height() - 210), NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow2), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow2), pPreviewBox);
 	gtk_box_pack_start (GTK_BOX (pKeyBox), pScrolledWindow2, FALSE, FALSE, 0);
