@@ -41,6 +41,7 @@
 #include "cairo-dock-draw-opengl.h"  // cairo_dock_create_texture_from_surface
 #include "cairo-dock-compiz-integration.h"
 #include "cairo-dock-kwin-integration.h"
+#include "cairo-dock-gnome-shell-integration.h"
 #define _MANAGER_DEF_
 #include "cairo-dock-X-manager.h"
 
@@ -66,6 +67,7 @@ static Atom s_aNetWorkarea;
 static Atom s_aNetShowingDesktop;
 static Atom s_aRootMapID;
 static Atom s_aNetNbDesktops;
+static Atom s_aNetDesktopNames;
 static Atom s_aXKlavierState;
 static CairoDockDesktopBackground *s_pDesktopBg = NULL;  // une fois alloue, le pointeur restera le meme tout le temps.
 static CairoDockWMBackend *s_pWMBackend = NULL;
@@ -80,8 +82,8 @@ static inline void _cairo_dock_retrieve_current_desktop_and_viewport (void)
 {
 	g_desktopGeometry.iCurrentDesktop = cairo_dock_get_current_desktop ();
 	cairo_dock_get_current_viewport (&g_desktopGeometry.iCurrentViewportX, &g_desktopGeometry.iCurrentViewportY);
-	g_desktopGeometry.iCurrentViewportX /= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-	g_desktopGeometry.iCurrentViewportY /= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+	g_desktopGeometry.iCurrentViewportX /= gldi_get_desktop_width();
+	g_desktopGeometry.iCurrentViewportY /= gldi_get_desktop_height();
 }
 
 static gboolean _on_change_current_desktop_viewport (void)
@@ -177,6 +179,10 @@ static gboolean _cairo_dock_unstack_Xevents (G_GNUC_UNUSED gpointer data)
 				{
 					cairo_dock_notify_on_object (&myDesktopMgr, NOTIFICATION_KBD_STATE_CHANGED, NULL);
 				}
+				else if (event.xproperty.atom == s_aNetDesktopNames)
+				{
+					cairo_dock_notify_on_object (&myDesktopMgr, NOTIFICATION_DESKTOP_NAMES_CHANGED);
+				}
 			}  // fin de PropertyNotify sur root.
 		}
 		else  // evenement sur une fenetre.
@@ -346,8 +352,8 @@ static cairo_surface_t *_cairo_dock_create_surface_from_desktop_bg (void)  // at
 			cd_debug ("c'est une couleur unie (%.2f, %.2f, %.2f)", (double) pixels[0] / 255, (double) pixels[1] / 255, (double) pixels[2] / 255);
 			
 			pDesktopBgSurface = cairo_dock_create_blank_surface (
-				g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL],
-				g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+				gldi_get_desktop_width(),
+				gldi_get_desktop_height());
 			
 			cairo_t *pCairoContext = cairo_create (pDesktopBgSurface);
 			cairo_set_source_rgb (pCairoContext,
@@ -370,12 +376,12 @@ static cairo_surface_t *_cairo_dock_create_surface_from_desktop_bg (void)  // at
 				&fHeight,
 				NULL, NULL);
 			
-			if (fWidth < g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] || fHeight < g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL])
+			if (fWidth < gldi_get_desktop_width() || fHeight < gldi_get_desktop_height())
 			{
 				cd_debug ("c'est un degrade ou un motif (%dx%d)", (int) fWidth, (int) fHeight);
 				pDesktopBgSurface = cairo_dock_create_blank_surface (
-					g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL],
-					g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+					gldi_get_desktop_width(),
+					gldi_get_desktop_height());
 				cairo_t *pCairoContext = cairo_create (pDesktopBgSurface);
 				
 				cairo_pattern_t *pPattern = cairo_pattern_create_for_surface (pBgSurface);
@@ -533,6 +539,7 @@ static void init (void)
 	s_aNetShowingDesktop 	= XInternAtom (s_XDisplay, "_NET_SHOWING_DESKTOP", False);
 	s_aRootMapID			= XInternAtom (s_XDisplay, "_XROOTPMAP_ID", False);  // Note: ESETROOT_PMAP_ID might be used instead. We don't handle it as it seems quite rare and somewhat deprecated.
 	s_aNetNbDesktops		= XInternAtom (s_XDisplay, "_NET_NUMBER_OF_DESKTOPS", False);
+	s_aNetDesktopNames			= XInternAtom (s_XDisplay, "_NET_DESKTOP_NAMES", False);
 	s_aXKlavierState		= XInternAtom (s_XDisplay, "XKLAVIER_STATE", False);
 	
 	//\__________________ On recupere le bureau courant.
@@ -550,6 +557,7 @@ static void init (void)
 	//\__________________ Init the Window Manager backends.
 	cd_init_compiz_backend ();
 	cd_init_kwin_backend ();
+	cd_init_gnome_shell_backend ();
 }
 
 
