@@ -43,6 +43,10 @@ gboolean cairo_dock_update_screen_geometry (void);
 
 gboolean cairo_dock_property_is_present_on_root (const gchar *cPropertyName);
 
+gchar **cairo_dock_get_desktops_names (void);
+
+void cairo_dock_set_desktops_names (gchar **cNames);
+
 
 int cairo_dock_get_current_desktop (void);
 void cairo_dock_get_current_viewport (int *iCurrentViewPortX, int *iCurrentViewPortY);
@@ -68,7 +72,7 @@ gboolean cairo_dock_xinerama_is_available (void);
 gboolean cairo_dock_check_xrandr (int major, int minor);  // returns TRUE if the version is supported
 
 
-void cairo_dock_get_screen_offsets (int iNumScreen, int *iScreenOffsetX, int *iScreenOffsetY);
+///void cairo_dock_get_screen_offsets (int iNumScreen, int *iScreenOffsetX, int *iScreenOffsetY);
 
 
   ////////////
@@ -93,6 +97,7 @@ void cairo_dock_lower_xwindow (Window Xid);
 void cairo_dock_maximize_xwindow (Window Xid, gboolean bMaximize);
 void cairo_dock_set_xwindow_fullscreen (Window Xid, gboolean bFullScreen);
 void cairo_dock_set_xwindow_above (Window Xid, gboolean bAbove);
+void cairo_dock_set_xwindow_sticky (Window Xid, gboolean bSticky);
 void cairo_dock_move_xwindow_to_nth_desktop (Window Xid, int iDesktopNumber, int iDesktopViewportX, int iDesktopViewportY);
 void cairo_dock_move_xwindow_to_absolute_position (Window Xid, int iDesktopNumber, int iPositionX, int iPositionY);
 
@@ -110,6 +115,7 @@ gchar *cairo_dock_get_xwindow_class (Window Xid, gchar **cWMClass);
 gboolean cairo_dock_xwindow_is_maximized (Window Xid);
 gboolean cairo_dock_xwindow_is_fullscreen (Window Xid);
 gboolean cairo_dock_xwindow_skip_taskbar (Window Xid);
+gboolean cairo_dock_xwindow_is_sticky (Window Xid);
 void cairo_dock_xwindow_is_above_or_below (Window Xid, gboolean *bIsAbove, gboolean *bIsBelow);
 gboolean cairo_dock_xwindow_is_fullscreen_or_hidden_or_maximized (Window Xid, gboolean *bIsFullScreen, gboolean *bIsHidden, gboolean *bIsMaximized, gboolean *bDemandsAttention);
 gboolean cairo_dock_window_is_utility (int Xid);
