@@ -618,7 +618,7 @@ cairo_surface_t *cairo_dock_duplicate_inhibitor_surface_for_appli (Icon *pInhibi
 	int w, h;
 	cairo_dock_get_icon_extent (pInhibitorIcon, &w, &h);
 	
-	return cairo_dock_duplicate_surface (pInhibitorIcon->pIconBuffer,
+	return cairo_dock_duplicate_surface (pInhibitorIcon->image.pSurface,
 		w,
 		h,
 		iWidth,
@@ -835,8 +835,8 @@ Icon *cairo_dock_get_classmate (Icon *pIcon)
 		pFriendIcon = pElement->data;
 		if (pFriendIcon == pIcon)  // skip ourselves
 			continue ;
-		if (pFriendIcon->cParentDockName != NULL && strcmp (pFriendIcon->cParentDockName, pIcon->cClass) != 0)  // inside a dock, but not the class sub-dock
-		//if (pFriendIcon != pIcon && pFriendIcon->cParentDockName != NULL && strcmp (pFriendIcon->cParentDockName, CAIRO_DOCK_MAIN_DOCK_NAME) == 0)  // is inside a dock
+		
+		if (pFriendIcon->cParentDockName != NULL && (pClassAppli->cDockName == NULL || strcmp (pFriendIcon->cParentDockName, pClassAppli->cDockName) != 0))  // inside a dock, but not the class sub-dock
 			return pFriendIcon;
 	}
 	
@@ -1161,8 +1161,8 @@ static inline double _get_first_appli_order (CairoDock *pDock, GList *first_laun
 			for (ic = pDock->icons; ic != NULL; ic = ic->next)
 			{
 				icon = ic->data;
-				if ((icon->cDesktopFileName != NULL && strcmp (icon->cDesktopFileName, myTaskbarParam.cRelativeIconName) == 0)
-				|| (icon->pModuleInstance && strcmp (icon->pModuleInstance->cConfFilePath, myTaskbarParam.cRelativeIconName) == 0))
+				if ((icon->cDesktopFileName != NULL && g_strcmp0 (icon->cDesktopFileName, myTaskbarParam.cRelativeIconName) == 0)
+				|| (icon->pModuleInstance && g_strcmp0 (icon->pModuleInstance->cConfFilePath, myTaskbarParam.cRelativeIconName) == 0))
 					break;
 			}
 			
@@ -1440,7 +1440,7 @@ void cairo_dock_set_class_order_amongst_applis (Icon *pIcon, CairoDock *pDock)
 			for (ic = first_appli_ic; ic != NULL; ic = ic->next)
 			{
 				icon = ic->data;
-				if (! CAIRO_DOCK_ICON_TYPE_IS_APPLI (icon))
+				if (! CAIRO_DOCK_ICON_TYPE_IS_APPLI (icon) && ! CAIRO_DOCK_IS_MULTI_APPLI (icon))
 					break;
 				
 				// get the age of this class (= age of the oldest icon of this class)
@@ -1555,28 +1555,18 @@ const CairoDockImageBuffer *cairo_dock_get_class_image_buffer (const gchar *cCla
 	for (ic = pClassAppli->pIconsOfClass; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (pIcon) && pIcon->pIconBuffer)  // avoid applets
+		if (CAIRO_DOCK_ICON_TYPE_IS_LAUNCHER (pIcon) && pIcon->image.pSurface)  // avoid applets
 		{
-			int iWidth, iHeight;
-			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-			image.pSurface = pIcon->pIconBuffer;  // since we got the texture with the load(), we don't use the image buffer constructor.
-			image.iWidth = iWidth;
-			image.iHeight = iHeight;
-			image.iTexture = pIcon->iIconTexture;
+			memcpy (&image, &pIcon->image, sizeof (CairoDockImageBuffer));
 			return &image;
 		}
 	}
 	for (ic = pClassAppli->pAppliOfClass; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		if (pIcon->pIconBuffer)
+		if (pIcon->image.pSurface)
 		{
-			int iWidth, iHeight;
-			cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
-			image.pSurface = pIcon->pIconBuffer;  // since we got the texture with the load(), we don't use the image buffer constructor.
-			image.iWidth = iWidth;
-			image.iHeight = iHeight;
-			image.iTexture = pIcon->iIconTexture;
+			memcpy (&image, &pIcon->image, sizeof (CairoDockImageBuffer));
 			return &image;
 		}
 	}
