@@ -26,10 +26,13 @@
 #include <stdlib.h>
 
 #include "gldi-config.h"
-#ifdef HAVE_LIBCRYPT
-/* libC crypt */
-#include <crypt.h>
 
+#ifdef HAVE_LIBCRYPT
+#ifdef __FreeBSD__
+#include <unistd.h>  // on BSD, there is no crypt.h
+#else
+#include <crypt.h>
+#endif
 static char DES_crypt_key[64] =
 {
     1,0,0,1,1,1,0,0, 1,0,1,1,1,0,1,1, 1,1,0,1,0,1,0,1, 1,1,0,0,0,0,0,1,
@@ -41,7 +44,7 @@ static char DES_crypt_key[64] =
 #include "cairo-dock-icon-manager.h"  // cairo_dock_hide_show_launchers_on_other_desktops
 #include "cairo-dock-applications-manager.h"  // cairo_dock_start_applications_manager
 #include "cairo-dock-module-factory.h"  // cairo_dock_activate_modules_from_list
-#include "cairo-dock-keyfile-utilities.h"  // cairo_dock_update_conf_file
+#include "cairo-dock-themes-manager.h"  // cairo_dock_update_conf_file
 #include "cairo-dock-dock-manager.h"  // cairo_dock_create_dock
 #include "cairo-dock-file-manager.h"  // cairo_dock_get_file_size
 #include "cairo-dock-launcher-manager.h"  // cairo_dock_load_launchers_from_dir
@@ -458,7 +461,7 @@ void cairo_dock_load_current_theme (void)
 	//\___________________ Now load the launchers.
 	cairo_dock_load_launchers_from_dir (g_cCurrentLaunchersPath);
 	
-	cairo_dock_hide_show_launchers_on_other_desktops (pMainDock);
+	cairo_dock_hide_show_launchers_on_other_desktops ();
 	
 	//\___________________ Load the applets.
 	cairo_dock_activate_modules_from_list (myModulesParam.cActiveModuleList);
@@ -466,13 +469,6 @@ void cairo_dock_load_current_theme (void)
 	//\___________________ Start the applications manager (will load the icons if the option is enabled).
 	cairo_dock_start_applications_manager (pMainDock);
 	
-	//\___________________ Draw everything.
-	///cairo_dock_draw_subdock_icons ();  // maintenant que les sous-docks sont tous definis.
-	
-	//cairo_dock_update_all_docks_size ();
-	///cairo_dock_set_all_views_to_default (0);  // met a jour la taille de tous les docks, maintenant qu'ils sont tous remplis.
-	///cairo_dock_redraw_root_docks (FALSE);  // FALSE <=> main dock inclus.
-	
 	//\___________________ On charge les decorations des desklets.
 	/**if (myDeskletsParam.cDeskletDecorationsName != NULL)  // chargement initial, on charge juste ceux qui n'ont pas encore leur deco et qui ont atteint leur taille definitive.
 	{
