@@ -39,7 +39,7 @@
 #include "cairo-dock-opengl.h"
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-animations.h"  // cairo_dock_animation_will_be_visible
-#include "cairo-dock-X-manager.h"  // g_desktopGeometry
+#include "cairo-dock-X-manager.h"  // gldi_get_desktop_width
 #define _MANAGER_DEF_
 #include "cairo-dock-container.h"
 
@@ -48,13 +48,11 @@ CairoContainersParam myContainersParam;
 CairoContainersManager myContainersMgr;
 CairoContainer *g_pPrimaryContainer = NULL;
 CairoDockDesktopBackground *g_pFakeTransparencyDesktopBg = NULL;
-gboolean g_bUseGlitz = FALSE;
 
 // dependancies
 extern CairoDockGLConfig g_openglConfig;
 extern gboolean g_bUseOpenGL;
 extern CairoDockHidingEffect *g_pHidingBackend;  // cairo_dock_is_hidden
-extern CairoDockDesktopGeometry g_desktopGeometry;  // _place_menu_on_icon
 
 // private
 static gboolean s_bSticky = TRUE;
@@ -206,7 +204,8 @@ GtkWidget *cairo_dock_init_container_full (CairoContainer *pContainer, gboolean
 	gtk_window_set_has_resize_grip (GTK_WINDOW(pWindow), FALSE);
 	#endif
 	
-	gldi_object_set_manager (GLDI_OBJECT (pContainer), GLDI_MANAGER (&myContainersMgr));  // the implementation of the container will set its manager on top of this one.
+	if (GLDI_OBJECT (pContainer)->mgr == NULL)
+		gldi_object_set_manager (GLDI_OBJECT (pContainer), GLDI_MANAGER (&myContainersMgr));  // the implementation of the container will set its manager on top of this one.
 	
 	if (g_pPrimaryContainer == NULL)
 	{
@@ -215,6 +214,7 @@ GtkWidget *cairo_dock_init_container_full (CairoContainer *pContainer, gboolean
 	return pWindow;
 }
 
+
 void cairo_dock_finish_container (CairoContainer *pContainer)
 {
 	gldi_glx_finish_container (pContainer);
@@ -339,8 +339,8 @@ void cairo_dock_allow_widget_to_receive_data (GtkWidget *pWidget, GCallback pCal
 		NULL,
 		0,
 		GDK_ACTION_COPY | GDK_ACTION_MOVE);  // le 'GDK_ACTION_MOVE' c'est pour KDE.
-	gtk_drag_dest_add_text_targets (pWidget);
 	gtk_drag_dest_add_uri_targets (pWidget);
+	gtk_drag_dest_add_text_targets (pWidget);
 	
 	g_signal_connect (G_OBJECT (pWidget),
 		"drag_data_received",
@@ -456,19 +456,20 @@ static void _place_menu_on_icon (GtkMenu *menu, gint *x, gint *y, gboolean *push
 	w = requisition.width;
 	h = requisition.height;
 	
+	int Hs = (pContainer->bIsHorizontal ? gldi_get_desktop_height() : gldi_get_desktop_width());
 	//g_print ("%d;%d %dx%d\n", x0, y0, w, h);
 	if (pContainer->bIsHorizontal)
 	{
 		*x = x0;
-		if (y0 > g_desktopGeometry.iXScreenHeight[pContainer->bIsHorizontal]/2)  // pContainer->bDirectionUp
+		if (y0 > Hs/2)  // pContainer->bDirectionUp
 			*y = y0 - h;
 		else
 			*y = y0 + pIcon->fHeight * pIcon->fScale;
 	}
 	else
 	{
-		*y = MIN (x0, g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - h);
-		if (y0 > g_desktopGeometry.iXScreenHeight[pContainer->bIsHorizontal]/2)  // pContainer->bDirectionUp
+		*y = MIN (x0, gldi_get_desktop_height() - h);
+		if (y0 > Hs/2)  // pContainer->bDirectionUp
 			*x = y0 - w;
 		else
 			*x = y0 + pIcon->fHeight * pIcon->fScale;
