@@ -28,9 +28,9 @@
 #include <string.h>
 #include <math.h>
 
-#include <GL/gl.h> 
-#include <GL/glu.h> 
-#include <GL/glx.h> 
+#include <GL/gl.h>
+#include <GL/glu.h>
+#include <GL/glx.h>
 
 #include <gdk/gdkx.h>
 #include "cairo-dock-draw.h"
@@ -40,7 +40,7 @@
 #include "cairo-dock-dialog-manager.h"
 #include "cairo-dock-icon-factory.h"
 #include "cairo-dock-icon-facility.h"
-#include "cairo-dock-keyfile-utilities.h"
+#include "cairo-dock-themes-manager.h"  // cairo_dock_update_conf_file
 #include "cairo-dock-X-manager.h"
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-log.h"
@@ -57,7 +57,6 @@
 #include "cairo-dock-desklet-factory.h"
 
 extern gboolean g_bUseOpenGL;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 
 static void _cairo_dock_reserve_space_for_desklet (CairoDesklet *pDesklet, gboolean bReserve);
 static void on_drag_data_received_desklet (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint t, CairoDesklet *pDesklet);
@@ -166,12 +165,9 @@ static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 				
 				// on recharge l'icone principale.
 				Icon* pIcon = pDesklet->pIcon;
-				if (pIcon)
+				if (pIcon)  // if the view doesn't display the main icon, it will set the allocated size to 0 so that the icon won't be loaded.
 				{
-					pIcon->iImageWidth = pIcon->fWidth;
-					pIcon->iImageHeight = pIcon->fHeight;
-					if (pIcon->iImageWidth > 0)  // the view displays the main icon -> load it.
-						cairo_dock_load_icon_buffers (pIcon, CAIRO_CONTAINER (pDesklet));  // pas de trigger, car on veut pouvoir associer un contexte a l'icone principale tout de suite.
+					cairo_dock_load_icon_buffers (pIcon, CAIRO_CONTAINER (pDesklet));  // pas de trigger, car on veut pouvoir associer un contexte a l'icone principale tout de suite.
 				}
 				
 				// on recharge chaque icone.
@@ -179,10 +175,8 @@ static gboolean _cairo_dock_write_desklet_size (CairoDesklet *pDesklet)
 				for (ic = pDesklet->icons; ic != NULL; ic = ic->next)
 				{
 					pIcon = ic->data;
-					if ((int)pIcon->fWidth != pIcon->iImageWidth || (int)pIcon->fHeight != pIcon->iImageHeight)
+					if (cairo_dock_icon_get_allocated_width (pIcon) != pIcon->image.iWidth || cairo_dock_icon_get_allocated_height (pIcon) != pIcon->image.iHeight)
 					{
-						pIcon->iImageWidth = pIcon->fWidth;
-						pIcon->iImageHeight = pIcon->fHeight;
 						cairo_dock_trigger_load_icon_buffers (pIcon);
 					}
 				}
@@ -211,8 +205,8 @@ static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
 {
 	if (pDesklet->pIcon != NULL && pDesklet->pIcon->pModuleInstance != NULL)
 	{
-		int iRelativePositionX = (pDesklet->container.iWindowPositionX + pDesklet->container.iWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2 ? pDesklet->container.iWindowPositionX : pDesklet->container.iWindowPositionX - g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
-		int iRelativePositionY = (pDesklet->container.iWindowPositionY + pDesklet->container.iHeight/2 <= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]/2 ? pDesklet->container.iWindowPositionY : pDesklet->container.iWindowPositionY - g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
+		int iRelativePositionX = (pDesklet->container.iWindowPositionX + pDesklet->container.iWidth/2 <= gldi_get_desktop_width()/2 ? pDesklet->container.iWindowPositionX : pDesklet->container.iWindowPositionX - gldi_get_desktop_width());
+		int iRelativePositionY = (pDesklet->container.iWindowPositionY + pDesklet->container.iHeight/2 <= gldi_get_desktop_height()/2 ? pDesklet->container.iWindowPositionY : pDesklet->container.iWindowPositionY - gldi_get_desktop_height());
 		
 		int iNumDesktop = -1;
 		if (! cairo_dock_desklet_is_sticky (pDesklet))
@@ -223,12 +217,12 @@ static gboolean _cairo_dock_write_desklet_position (CairoDesklet *pDesklet)
 			int iGlobalPositionX, iGlobalPositionY, iWidthExtent, iHeightExtent;
 			cairo_dock_get_xwindow_geometry (Xid, &iGlobalPositionX, &iGlobalPositionY, &iWidthExtent, &iHeightExtent);
 			if (iGlobalPositionX < 0)
-				iGlobalPositionX += g_desktopGeometry.iNbViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
+				iGlobalPositionX += g_desktopGeometry.iNbViewportX * gldi_get_desktop_width();
 			if (iGlobalPositionY < 0)
-				iGlobalPositionY += g_desktopGeometry.iNbViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+				iGlobalPositionY += g_desktopGeometry.iNbViewportY * gldi_get_desktop_height();
 			
-			int iViewportX = iGlobalPositionX / g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-			int iViewportY = iGlobalPositionY / g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+			int iViewportX = iGlobalPositionX / gldi_get_desktop_width();
+			int iViewportY = iGlobalPositionY / gldi_get_desktop_height();
 			
 			int iCurrentDesktop, iCurrentViewportX, iCurrentViewportY;
 			cairo_dock_get_current_desktop_and_viewport (&iCurrentDesktop, &iCurrentViewportX, &iCurrentViewportY);
@@ -307,13 +301,13 @@ static gboolean on_configure_desklet (G_GNUC_UNUSED GtkWidget* pWidget,
 	int x = pEvent->x, y = pEvent->y;
 	//g_print ("new desklet position : (%d;%d)", x, y);
 	while (x < 0)  // on passe au referentiel du viewport de la fenetre; inutile de connaitre sa position, puisqu'ils ont tous la meme taille.
-		x += g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
-	while (x >= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL])
-		x -= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL];
+		x += gldi_get_desktop_width();
+	while (x >= gldi_get_desktop_width())
+		x -= gldi_get_desktop_width();
 	while (y < 0)
-		y += g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
-	while (y >= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL])
-		y -= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL];
+		y += gldi_get_desktop_height();
+	while (y >= gldi_get_desktop_height())
+		y -= gldi_get_desktop_height();
 	//g_print (" => (%d;%d)\n", x, y);
 	if (pDesklet->container.iWindowPositionX != x || pDesklet->container.iWindowPositionY != y)
 	{
@@ -338,12 +332,13 @@ static gboolean on_scroll_desklet (G_GNUC_UNUSED GtkWidget* pWidget,
 	GdkEventScroll* pScroll,
 	CairoDesklet *pDesklet)
 {
-	//g_print ("scroll\n");
-	if (! (pScroll->state & (GDK_SHIFT_MASK | GDK_CONTROL_MASK)))
+	//g_print ("scroll %d\n", pScroll->direction);
+	if (pScroll->direction != GDK_SCROLL_UP && pScroll->direction != GDK_SCROLL_DOWN)  // on degage les scrolls horizontaux.
 	{
-		Icon *icon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);  // can be NULL
-		cairo_dock_notify_on_object (pDesklet, NOTIFICATION_SCROLL_ICON, icon, pDesklet, pScroll->direction);
+		return FALSE;
 	}
+	Icon *icon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);  // can be NULL
+	cairo_dock_notify_on_object (pDesklet, NOTIFICATION_SCROLL_ICON, icon, pDesklet, pScroll->direction);
 	return FALSE;
 }
 
@@ -503,8 +498,6 @@ static gboolean on_button_press_desklet(G_GNUC_UNUSED GtkWidget *pWidget,
 		Icon *pClickedIcon = cairo_dock_find_clicked_icon_in_desklet (pDesklet);
 		GtkWidget *menu = cairo_dock_build_menu (pClickedIcon, CAIRO_CONTAINER (pDesklet));  // genere un CAIRO_DOCK_BUILD_ICON_MENU.
 		cairo_dock_popup_menu_on_container (menu, CAIRO_CONTAINER (pDesklet));
-		pDesklet->container.bInside = FALSE;
-		gtk_widget_queue_draw (pDesklet->container.pWidget);
 	}
 	else if (pButton->button == 2 && pButton->type == GDK_BUTTON_PRESS)  // clique milieu.
 	{
@@ -632,7 +625,7 @@ static gboolean on_motion_notify_desklet (GtkWidget *pWidget,
 				pPointedIcon->bPointed = FALSE;
 				
 				//g_print ("kedal\n");
-				cairo_dock_notify_on_object (pDesklet, NOTIFICATION_ENTER_ICON, pPointedIcon, pDesklet, &bStartAnimation);
+				//cairo_dock_notify_on_object (pDesklet, NOTIFICATION_ENTER_ICON, pPointedIcon, pDesklet, &bStartAnimation);
 			}
 		}
 		if (bStartAnimation)
@@ -675,12 +668,12 @@ static gboolean on_leave_desklet (GtkWidget* pWidget,
 	GdkEventCrossing* pEvent,
 	CairoDesklet *pDesklet)
 {
-	//g_print ("%s (%d)\n", __func__, pDesklet->container.bInside);
+	//g_print ("%s (%d, %p, %d;%d)\n", __func__, pDesklet->container.bInside, pEvent, iMouseX, iMouseY);
 	int iMouseX, iMouseY;
 	if (pEvent != NULL)
 	{
-		iMouseX = pEvent->x_root;
-		iMouseY = pEvent->y_root;
+		iMouseX = pEvent->x;
+		iMouseY = pEvent->y;
 	}
 	else
 	{
@@ -692,8 +685,11 @@ static gboolean on_leave_desklet (GtkWidget* pWidget,
 	{
 		return FALSE;
 	}
-
+	
 	pDesklet->container.bInside = FALSE;
+	Icon *pPointedIcon = cairo_dock_get_pointed_icon (pDesklet->icons);
+	if (pPointedIcon != NULL)
+		pPointedIcon->bPointed = FALSE;
 	gtk_widget_queue_draw (pWidget);  // redessin des boutons.
 	
 	gboolean bStartAnimation = FALSE;
@@ -758,25 +754,22 @@ static gboolean _cairo_desklet_animation_loop (CairoContainer *pContainer)
 
 CairoDesklet *cairo_dock_new_desklet (void)
 {
-	cd_message ("%s ()", __func__);
-	CairoDesklet *pDesklet = g_new0(CairoDesklet, 1);
-	pDesklet->container.iType = CAIRO_DOCK_TYPE_DESKLET;
+	// Create a desklet
+	CairoDesklet *pDesklet = gldi_container_new (CairoDesklet, &myDeskletsMgr, CAIRO_DOCK_TYPE_DESKLET);
+	
 	pDesklet->container.bIsHorizontal = TRUE;
 	pDesklet->container.bDirectionUp = TRUE;
 	pDesklet->container.fRatio = 1;
-	pDesklet->container.fRatio = 1;
-	
 	pDesklet->container.iface.animation_loop = _cairo_desklet_animation_loop;
 	
-	GtkWidget* pWindow = cairo_dock_init_container (CAIRO_CONTAINER (pDesklet));
-	gldi_object_set_manager (GLDI_OBJECT (pDesklet), GLDI_MANAGER (&myDeskletsMgr));
-	
+	// set up its window
+	GtkWidget *pWindow = pDesklet->container.pWidget;
 	gtk_window_set_title (GTK_WINDOW(pWindow), "cairo-dock-desklet");
 	gtk_widget_add_events( pWindow,
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_SCROLL_MASK |
 		GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK | GDK_FOCUS_CHANGE_MASK |
 		GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
-	gtk_container_set_border_width(GTK_CONTAINER(pWindow), 1);  // comme ca.
+	gtk_container_set_border_width(GTK_CONTAINER(pWindow), 1);
 	
 	g_signal_connect (G_OBJECT (pWindow),
 		#if (GTK_MAJOR_VERSION < 3)
@@ -889,10 +882,10 @@ void cairo_dock_configure_desklet (CairoDesklet *pDesklet, CairoDeskletAttribute
 		gtk_window_set_resizable (GTK_WINDOW(pDesklet->container.pWidget), FALSE);
 	}
 	
-	int iAbsolutePositionX = (pAttribute->iDeskletPositionX < 0 ? g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] + pAttribute->iDeskletPositionX : pAttribute->iDeskletPositionX);
-	iAbsolutePositionX = MAX (0, MIN (g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - pAttribute->iDeskletWidth, iAbsolutePositionX));
-	int iAbsolutePositionY = (pAttribute->iDeskletPositionY < 0 ? g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] + pAttribute->iDeskletPositionY : pAttribute->iDeskletPositionY);
-	iAbsolutePositionY = MAX (0, MIN (g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - pAttribute->iDeskletHeight, iAbsolutePositionY));
+	int iAbsolutePositionX = (pAttribute->iDeskletPositionX < 0 ? gldi_get_desktop_width() + pAttribute->iDeskletPositionX : pAttribute->iDeskletPositionX);
+	iAbsolutePositionX = MAX (0, MIN (gldi_get_desktop_width() - pAttribute->iDeskletWidth, iAbsolutePositionX));
+	int iAbsolutePositionY = (pAttribute->iDeskletPositionY < 0 ? gldi_get_desktop_height() + pAttribute->iDeskletPositionY : pAttribute->iDeskletPositionY);
+	iAbsolutePositionY = MAX (0, MIN (gldi_get_desktop_height() - pAttribute->iDeskletHeight, iAbsolutePositionY));
 	
 	if (pAttribute->bOnAllDesktops)
 		gdk_window_move (gldi_container_get_gdk_window (CAIRO_CONTAINER (pDesklet)),
@@ -925,8 +918,8 @@ void cairo_dock_configure_desklet (CairoDesklet *pDesklet, CairoDeskletAttribute
 			iNumViewportX -= iCurrentViewportX;
 			iNumViewportY -= iCurrentViewportY;
 			
-			cd_debug ("on le place en %d + %d", iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL], iAbsolutePositionX);
-			cairo_dock_move_xwindow_to_absolute_position (Xid, iNumDesktop, iNumViewportX * g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] + iAbsolutePositionX, iNumViewportY * g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] + iAbsolutePositionY);
+			cd_debug ("on le place en %d + %d", iNumViewportX * gldi_get_desktop_width(), iAbsolutePositionX);
+			cairo_dock_move_xwindow_to_absolute_position (Xid, iNumDesktop, iNumViewportX * gldi_get_desktop_width() + iAbsolutePositionX, iNumViewportY * gldi_get_desktop_height() + iAbsolutePositionY);
 		}
 	}
 	pDesklet->bPositionLocked = pAttribute->bPositionLocked;
@@ -1122,9 +1115,9 @@ static void _cairo_dock_reserve_space_for_desklet (CairoDesklet *pDesklet, gbool
 	{
 		int iTopOffset, iBottomOffset, iRightOffset, iLeftOffset;
 		iTopOffset = iY;
-		iBottomOffset = g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL] - 1 - (iY + iHeight);
+		iBottomOffset = gldi_get_desktop_height() - 1 - (iY + iHeight);
 		iLeftOffset = iX;
-		iRightOffset = g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL] - 1 - (iX + iWidth);
+		iRightOffset = gldi_get_desktop_width() - 1 - (iX + iWidth);
 		
 		if (iBottomOffset < MIN (iLeftOffset, iRightOffset))  // en bas.
 		{
@@ -1254,10 +1247,8 @@ void cairo_dock_update_desklet_icons (CairoDesklet *pDesklet)
 	for (ic = pDesklet->icons; ic != NULL; ic = ic->next)
 	{
 		pIcon = ic->data;
-		if ((int)pIcon->fWidth != pIcon->iImageWidth || (int)pIcon->fHeight != pIcon->iImageHeight)
+		if (cairo_dock_icon_get_allocated_width (pIcon) != pIcon->image.iWidth || cairo_dock_icon_get_allocated_height (pIcon) != pIcon->image.iHeight)
 		{
-			pIcon->iImageWidth = pIcon->fWidth;
-			pIcon->iImageHeight = pIcon->fHeight;
 			cairo_dock_trigger_load_icon_buffers (pIcon);
 		}
 	}
