@@ -18,51 +18,26 @@
 */
 
 #include <math.h>
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <glib/gstdio.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
+#include <gdk/gdkx.h>  // GDK_WINDOW_XID
 
-#include <cairo.h>
-#include <pango/pango.h>
-
-#include <X11/extensions/Xrender.h>
-#include <X11/extensions/shape.h>
-#include <GL/gl.h> 
-#include <GL/glu.h> 
-#include <GL/glx.h> 
-
-#include "cairo-dock-draw.h"
-#include "cairo-dock-applications-manager.h"
-#include "cairo-dock-image-buffer.h"
-#include "cairo-dock-config.h"
-#include "cairo-dock-module-factory.h"
-#include "cairo-dock-callbacks.h"
-#include "cairo-dock-icon-factory.h"
+#include "cairo-dock-applications-manager.h"  // cairo_dock_set_icons_geometry_for_window_manager
 #include "cairo-dock-icon-facility.h"
-#include "cairo-dock-separator-factory.h"
-#include "cairo-dock-launcher-factory.h"
 #include "cairo-dock-backends-manager.h"  // myBackendsParam.fSubDockSizeRatio
-#include "cairo-dock-X-utilities.h"
+#include "cairo-dock-X-utilities.h" // cairo_dock_set_strut_partial
 #include "cairo-dock-log.h"
-#include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-dialog-manager.h"
+#include "cairo-dock-dialog-manager.h"  // cairo_dock_replace_all_dialogs
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-indicator-manager.h"  // myIndicators.bUseClassIndic
-#include "cairo-dock-class-manager.h"
 #include "cairo-dock-animations.h"
-#include "cairo-dock-X-manager.h"
-#include "cairo-dock-global-variables.h"
-#include "cairo-dock-data-renderer.h"
-#include "cairo-dock-opengl.h"
+#include "cairo-dock-X-manager.h"  // cairo_dock_get_screen_*
+#include "cairo-dock-global-variables.h"  // g_openglConfig
+#include "cairo-dock-data-renderer.h"  // cairo_dock_reload_data_renderer_on_icon
+#include "cairo-dock-opengl.h"  // gldi_glx_begin_draw_container_full
 
 #include "cairo-dock-dock-facility.h"
 
-extern CairoDockDesktopGeometry g_desktopGeometry;
 extern gboolean g_bUseOpenGL;  // for cairo_dock_make_preview()
 
 
@@ -110,6 +85,7 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 		pDock->iActiveHeight = pDock->iMaxDockHeight;
 	
 	// in case it's larger than the screen, iterate on the ratio until it fits the screen's width
+	int iScreenHeight = gldi_dock_get_screen_height (pDock);
 	double hmax = pDock->iMaxIconHeight;
 	int iMaxAuthorizedWidth = cairo_dock_get_max_authorized_dock_width (pDock);
 	int n = 0;  // counter to ensure we'll not loop forever.
@@ -133,9 +109,9 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 				pDock->container.fRatio = fMaxRatio;
 		}
 		
-		if (pDock->iMaxDockHeight > g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal])
+		if (pDock->iMaxDockHeight > iScreenHeight)
 		{
-			pDock->container.fRatio = MIN (pDock->container.fRatio, fPrevRatio * g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] / pDock->iMaxDockHeight);
+			pDock->container.fRatio = MIN (pDock->container.fRatio, fPrevRatio * iScreenHeight / pDock->iMaxDockHeight);
 		}
 		
 		if (fPrevRatio != pDock->container.fRatio)
@@ -163,7 +139,7 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 		
 		//g_print ("*** ratio : %.3f -> %.3f\n", fPrevRatio, pDock->container.fRatio);
 		n ++;
-	} while ((pDock->iMaxDockWidth > iMaxAuthorizedWidth || pDock->iMaxDockHeight > g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] || (pDock->container.fRatio < 1 && pDock->iMaxDockWidth < iMaxAuthorizedWidth-5)) && n < 8);
+	} while ((pDock->iMaxDockWidth > iMaxAuthorizedWidth || pDock->iMaxDockHeight > iScreenHeight || (pDock->container.fRatio < 1 && pDock->iMaxDockWidth < iMaxAuthorizedWidth-5)) && n < 8);
 	pDock->iMaxIconHeight = hmax;
 	//g_print (">>> iMaxIconHeight : %d, ratio : %.2f, fFlatDockWidth : %.2f\n", (int) pDock->iMaxIconHeight, pDock->container.fRatio, pDock->fFlatDockWidth);
 	
@@ -175,8 +151,12 @@ void cairo_dock_update_dock_size (CairoDock *pDock)  // iMaxIconHeight et fFlatD
 	if (iPrevMaxDockHeight == pDock->iMaxDockHeight && iPrevMaxDockWidth == pDock->iMaxDockWidth)  // if the size has changed, shapes will be updated by the "configure" callback, so we don't need to do it here; if not, we do it in case the icons define a new shape (ex.: separators in Panel view) or in case the screen edge has changed.
 	{
 		cairo_dock_update_input_shape (pDock);  // done after the icons' position is known.
-		if (pDock->container.bInside)  // if the mouse is inside, set the new input shape immediately.
-			cairo_dock_set_input_shape_active (pDock);
+		switch (pDock->iInputState)  // update the input zone
+		{
+			case CAIRO_DOCK_INPUT_ACTIVE: cairo_dock_set_input_shape_active (pDock);;
+			case CAIRO_DOCK_INPUT_AT_REST: cairo_dock_set_input_shape_at_rest (pDock);
+			default: break;  // if hidden, nothing to do.
+		}
 	}
 	
 	if (iPrevMaxDockHeight == pDock->iMaxDockHeight && iPrevMaxDockWidth == pDock->iMaxDockWidth)  // same remark as for the input shape.
@@ -291,6 +271,10 @@ Icon *cairo_dock_calculate_dock_icons (CairoDock *pDock)
  /// WINDOW SIZE AND POSITION ///
 ////////////////////////////////
 
+#define CANT_RESERVE_SPACE_WARNING "It's only possible to reserve space from the edge of the screen and not on the middle of two screens."
+
+#define _has_multiple_screens_and_on_one_screen(iNumScreen) (g_desktopGeometry.iNbScreens > 1 && iNumScreen > -1)
+
 void cairo_dock_reserve_space_for_dock (CairoDock *pDock, gboolean bReserve)
 {
 	Window Xid = gldi_container_get_Xid (CAIRO_CONTAINER (pDock));
@@ -301,41 +285,68 @@ void cairo_dock_reserve_space_for_dock (CairoDock *pDock, gboolean bReserve)
 	{
 		int w = pDock->iMinDockWidth;
 		int h = pDock->iMinDockHeight;
-		int x, y;  // position qu'aurait la fenetre du dock s'il avait la taille minimale.
+		int x, y;  // position that should have dock's window if it has a minimum size.
 		cairo_dock_get_window_position_at_balance (pDock, w, h, &x, &y);
-		
+
 		if (pDock->container.bDirectionUp)
 		{
 			if (pDock->container.bIsHorizontal)
 			{
-				bottom = h + pDock->iGapY;
-				bottom_start_x = x;
-				bottom_end_x = x + w;
+				if (_has_multiple_screens_and_on_one_screen (pDock->iNumScreen)
+					&& cairo_dock_get_screen_position_y (pDock->iNumScreen) // offset
+						+ cairo_dock_get_screen_height (pDock->iNumScreen)  // height of the current screen
+						< gldi_get_desktop_height ()) // total height
+					cd_warning (CANT_RESERVE_SPACE_WARNING);
+				else
+				{
+					bottom = h + pDock->iGapY;
+					bottom_start_x = x;
+					bottom_end_x = x + w;
+				}
 			}
 			else
 			{
-				right = h + pDock->iGapY;
-				right_start_y = x;
-				right_end_y = x + w;
+				if (_has_multiple_screens_and_on_one_screen (pDock->iNumScreen)
+					&& cairo_dock_get_screen_position_x (pDock->iNumScreen) // offset
+						+ cairo_dock_get_screen_width (pDock->iNumScreen)  // height of the current screen
+						< gldi_get_desktop_width ()) // total height
+					cd_warning (CANT_RESERVE_SPACE_WARNING);
+				else
+				{
+					right = h + pDock->iGapY;
+					right_start_y = x;
+					right_end_y = x + w;
+				}
 			}
 		}
 		else
 		{
 			if (pDock->container.bIsHorizontal)
 			{
-				top = h + pDock->iGapY;
-				top_start_x = x;
-				top_end_x = x + w;
+				if (_has_multiple_screens_and_on_one_screen (pDock->iNumScreen)
+					&& cairo_dock_get_screen_position_y (pDock->iNumScreen) > 0)
+					cd_warning (CANT_RESERVE_SPACE_WARNING);
+				else
+				{
+					top = h + pDock->iGapY;
+					top_start_x = x;
+					top_end_x = x + w;
+				}
 			}
 			else
 			{
-				left = h + pDock->iGapY;
-				left_start_y = x;
-				left_end_y = x + w;
+				if (_has_multiple_screens_and_on_one_screen (pDock->iNumScreen)
+					&& cairo_dock_get_screen_position_x (pDock->iNumScreen) > 0)
+					cd_warning (CANT_RESERVE_SPACE_WARNING);
+				else
+				{
+					left = h + pDock->iGapY;
+					left_start_y = x;
+					left_end_y = x + w;
+				}
 			}
 		}
 	}
-	
 	cairo_dock_set_strut_partial (Xid, left, right, top, bottom, left_start_y, left_end_y, right_start_y, right_end_y, top_start_x, top_end_x, bottom_start_x, bottom_end_x);
 }
 
@@ -346,27 +357,29 @@ void cairo_dock_prevent_dock_from_out_of_screen (CairoDock *pDock)
 	y = (pDock->container.bDirectionUp ? pDock->container.iWindowPositionY + pDock->container.iHeight : pDock->container.iWindowPositionY);
 	//cd_debug ("%s (%d;%d)", __func__, x, y);
 	
-	pDock->iGapX = x - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] * pDock->fAlign;
-	pDock->iGapY = (pDock->container.bDirectionUp ? g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - y : y);
+	int W = gldi_dock_get_screen_width (pDock), H = gldi_dock_get_screen_height (pDock);
+	pDock->iGapX = x - W * pDock->fAlign;
+	pDock->iGapY = (pDock->container.bDirectionUp ? H - y : y);
 	//cd_debug (" -> (%d;%d)", pDock->iGapX, pDock->iGapY);
 	
-	if (pDock->iGapX < - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal]/2)
-		pDock->iGapX = - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal]/2;
-	if (pDock->iGapX > g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal]/2)
-		pDock->iGapX = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal]/2;
+	if (pDock->iGapX < - W/2)
+		pDock->iGapX = - W/2;
+	if (pDock->iGapX > W/2)
+		pDock->iGapX = W/2;
 	if (pDock->iGapY < 0)
 		pDock->iGapY = 0;
-	if (pDock->iGapY > g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal])
-		pDock->iGapY = g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal];
+	if (pDock->iGapY > H)
+		pDock->iGapY = H;
 }
 
 #define CD_VISIBILITY_MARGIN 20
 void cairo_dock_get_window_position_at_balance (CairoDock *pDock, int iNewWidth, int iNewHeight, int *iNewPositionX, int *iNewPositionY)
 {
-	int iWindowPositionX = (g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - iNewWidth) * pDock->fAlign + pDock->iGapX;
+	int W = gldi_dock_get_screen_width (pDock), H = gldi_dock_get_screen_height (pDock);
+	int iWindowPositionX = (W - iNewWidth) * pDock->fAlign + pDock->iGapX;
 	if (pDock->iRefCount == 0 && pDock->fAlign != .5)
 		iWindowPositionX += (.5 - pDock->fAlign) * (pDock->iMaxDockWidth - iNewWidth);
-	int iWindowPositionY = (pDock->container.bDirectionUp ? g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - iNewHeight - pDock->iGapY : pDock->iGapY);
+	int iWindowPositionY = (pDock->container.bDirectionUp ? H - iNewHeight - pDock->iGapY : pDock->iGapY);
 	//g_print ("pDock->iGapX : %d => iWindowPositionX <- %d\n", pDock->iGapX, iWindowPositionX);
 	//g_print ("iNewHeight : %d -> pDock->container.iWindowPositionY <- %d\n", iNewHeight, iWindowPositionY);
 	
@@ -374,30 +387,31 @@ void cairo_dock_get_window_position_at_balance (CairoDock *pDock, int iNewWidth,
 	{
 		if (iWindowPositionX + iNewWidth < CD_VISIBILITY_MARGIN)
 			iWindowPositionX = CD_VISIBILITY_MARGIN - iNewWidth;
-		else if (iWindowPositionX > g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - CD_VISIBILITY_MARGIN)
-			iWindowPositionX = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - CD_VISIBILITY_MARGIN;
+		else if (iWindowPositionX > W - CD_VISIBILITY_MARGIN)
+			iWindowPositionX = W - CD_VISIBILITY_MARGIN;
 	}
 	else
 	{
 		if (iWindowPositionX < - pDock->iLeftMargin)
 			iWindowPositionX = - pDock->iLeftMargin;
-		else if (iWindowPositionX > g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - iNewWidth + pDock->iMinRightMargin)
-			iWindowPositionX = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - iNewWidth + pDock->iMinRightMargin;
+		else if (iWindowPositionX > W - iNewWidth + pDock->iMinRightMargin)
+			iWindowPositionX = W - iNewWidth + pDock->iMinRightMargin;
 	}
 	if (iWindowPositionY < - pDock->iMaxIconHeight)
 		iWindowPositionY = - pDock->iMaxIconHeight;
-	else if (iWindowPositionY > g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - iNewHeight + pDock->iMaxIconHeight)
-		iWindowPositionY = g_desktopGeometry.iScreenHeight[pDock->container.bIsHorizontal] - iNewHeight + pDock->iMaxIconHeight;
+	else if (iWindowPositionY > H - iNewHeight + pDock->iMaxIconHeight)
+		iWindowPositionY = H - iNewHeight + pDock->iMaxIconHeight;
 	
+	int iScreenOffsetX = gldi_dock_get_screen_offset_x (pDock), iScreenOffsetY = gldi_dock_get_screen_offset_y (pDock);
 	if (pDock->container.bIsHorizontal)
 	{
-		*iNewPositionX = iWindowPositionX + pDock->iScreenOffsetX;
-		*iNewPositionY = iWindowPositionY + pDock->iScreenOffsetY;
+		*iNewPositionX = iWindowPositionX + iScreenOffsetX;
+		*iNewPositionY = iWindowPositionY + iScreenOffsetY;
 	}
 	else
 	{
-		*iNewPositionX = iWindowPositionX + pDock->iScreenOffsetY;
-		*iNewPositionY = iWindowPositionY + pDock->iScreenOffsetX;
+		*iNewPositionX = iWindowPositionX + iScreenOffsetX;
+		*iNewPositionY = iWindowPositionY + iScreenOffsetY;
 	}
 	//g_print ("POSITION : %d+%d ; %d+%d\n", iWindowPositionX, pDock->iScreenOffsetX, iWindowPositionY, pDock->iScreenOffsetY);
 }
@@ -948,7 +962,7 @@ void cairo_dock_set_subdock_position_linear (Icon *pPointedIcon, CairoDock *pDoc
 	if (pSubDock->container.bIsHorizontal == pDock->container.bIsHorizontal)
 	{
 		pSubDock->fAlign = 0.5;
-		pSubDock->iGapX = iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] / 2;  // ici les sous-dock ont un alignement egal a 0.5
+		pSubDock->iGapX = iX + pDock->container.iWindowPositionX - gldi_dock_get_screen_offset_x (pDock) - gldi_dock_get_screen_width (pDock) / 2;  // ici les sous-dock ont un alignement egal a 0.5
 		pSubDock->iGapY = pDock->iGapY + pDock->iActiveHeight;
 	}
 	else
@@ -956,7 +970,7 @@ void cairo_dock_set_subdock_position_linear (Icon *pPointedIcon, CairoDock *pDoc
 		pSubDock->fAlign = (pDock->container.bDirectionUp ? 1 : 0);
 		pSubDock->iGapX = (pDock->iGapY + pDock->iActiveHeight) * (pDock->container.bDirectionUp ? -1 : 1);
 		if (pDock->container.bDirectionUp)
-			pSubDock->iGapY = g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] - (iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY)) - pSubDock->iMaxDockHeight / 2;  // les sous-dock ont un alignement egal a 1.
+			pSubDock->iGapY = gldi_dock_get_screen_width (pDock) - (iX + pDock->container.iWindowPositionX - gldi_dock_get_screen_offset_x (pDock)) - pSubDock->iMaxDockHeight / 2;  // les sous-dock ont un alignement egal a 1.
 		else
 			pSubDock->iGapY = iX + pDock->container.iWindowPositionX - pSubDock->iMaxDockHeight / 2;  // les sous-dock ont un alignement egal a 0.
 	}
@@ -1045,6 +1059,49 @@ void cairo_dock_show_subdock (Icon *pPointedIcon, CairoDock *pParentDock)
 }
 
 
+static gboolean _cairo_dock_dock_is_child (CairoDock *pCurrentDock, CairoDock *pSubDock)
+{
+	GList *pIconsList;
+	Icon *pIcon;
+	// check all icons of this dock (recursively)
+	for (pIconsList = pCurrentDock->icons; pIconsList != NULL; pIconsList = pIconsList->next)
+	{
+		pIcon = pIconsList->data;
+		if (/**CAIRO_DOCK_ICON_TYPE_CONTAINER (pIcon) && */pIcon->pSubDock != NULL  // only subdock...
+		&& (pIcon->pSubDock == pSubDock // this subdock is inside the current dock!
+			|| _cairo_dock_dock_is_child (pIcon->pSubDock, pSubDock))) // check recursively
+			return TRUE;
+	}
+	return FALSE;
+}
+static void _add_one_dock_to_list (G_GNUC_UNUSED const gchar *cName, CairoDock *pDock, gpointer *data)
+{
+	CairoDock *pParentDock = data[0];
+	CairoDock *pSubDock = data[1];
+	
+	// get user docks only
+	Icon *pPointingIcon = cairo_dock_search_icon_pointing_on_dock (pDock, NULL);
+	if (pPointingIcon && ! CAIRO_DOCK_ICON_TYPE_IS_CONTAINER (pPointingIcon))  // avoid sub-docks that are not from the theme (applet sub-docks, class sub-docks, etc).
+		return;
+	
+	// ignore the parent dock.
+	if (pDock == pParentDock)
+		return;
+	
+	// ignore any child sub-dock (if it's a subdock).
+	if (pSubDock != NULL
+	&& (pSubDock == pDock || _cairo_dock_dock_is_child (pSubDock, pDock)))
+		return;
+	
+	data[2] = g_list_prepend (data[2], pDock);
+}
+GList *cairo_dock_get_available_docks (CairoDock *pParentDock, CairoDock *pSubDock)  // avoid 'pParentDock', and 'pSubDock' and any of its children
+{
+	gpointer data[3] = {pParentDock, pSubDock, NULL};
+	cairo_dock_foreach_docks ((GHFunc)_add_one_dock_to_list, data);
+	return data[2];
+}
+
 
 static gboolean _redraw_subdock_content_idle (Icon *pIcon)
 {
@@ -1053,11 +1110,6 @@ static gboolean _redraw_subdock_content_idle (Icon *pIcon)
 	{
 		if (pIcon->pSubDock != NULL)
 		{
-			if (pDock->container.iWidth == 1 && pDock->container.iHeight == 1)  // if the GTK resize process has not yet ended, the window may be in an awkward state: the size is forced by GTK to 1x1, which causes the FBO to fail (obviously, 1x1 is too small).
-			{
-				pIcon->iSidRedrawSubdockContent = g_idle_add ((GSourceFunc) _redraw_subdock_content_idle, pIcon);
-				return FALSE;
-			}
 			cairo_dock_draw_subdock_content_on_icon (pIcon, pDock);
 		}
 		else  // l'icone a pu perdre son sous-dock entre-temps (exemple : une classe d'appli contenant 2 icones, dont on enleve l'une des 2.
@@ -1065,6 +1117,8 @@ static gboolean _redraw_subdock_content_idle (Icon *pIcon)
 			cairo_dock_reload_icon_image (pIcon, CAIRO_CONTAINER (pDock));
 		}
 		cairo_dock_redraw_icon (pIcon, CAIRO_CONTAINER (pDock));
+		if (pDock->iRefCount != 0 && ! pIcon->bDamaged)  // now that the icon image is correct, redraw the pointing icon if needed
+			cairo_dock_trigger_redraw_subdock_content (pDock);
 	}
 	pIcon->iSidRedrawSubdockContent = 0;
 	return FALSE;
@@ -1113,7 +1167,7 @@ void cairo_dock_trigger_set_WM_icons_geometry (CairoDock *pDock)
 	}
 }
 
-void cairo_dock_resize_icon_in_dock (Icon *pIcon, CairoDock *pDock)  // the request size is already set on the icon.
+void cairo_dock_resize_icon_in_dock (Icon *pIcon, CairoDock *pDock)  // resize the icon according to the requested size previously set on the icon.
 {
 	cairo_dock_set_icon_size_in_dock (pDock, pIcon);
 	
