@@ -18,50 +18,28 @@
 */
 
 #include <math.h>
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <glib/gstdio.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
-#include <cairo.h>
-
-#include <X11/extensions/Xrender.h>
-#include <X11/extensions/shape.h>
-#include <GL/gl.h> 
-#include <GL/glu.h> 
-#include <GL/glx.h> 
-
-#include "cairo-dock-draw.h"
-#include "cairo-dock-applications-manager.h"
-#include "cairo-dock-image-buffer.h"
+#include "cairo-dock-applications-manager.h"  // myTaskbarParam.bHideVisibleApplis
 #include "cairo-dock-module-factory.h"
 #include "cairo-dock-callbacks.h"
-#include "cairo-dock-icon-factory.h"
 #include "cairo-dock-icon-facility.h"
-#include "cairo-dock-separator-manager.h"
-#include "cairo-dock-launcher-manager.h"
+#include "cairo-dock-separator-manager.h"  // cairo_dock_insert_automatic_separator_in_dock
+#include "cairo-dock-launcher-manager.h"  // cairo_dock_create_icon_from_desktop_file
 #include "cairo-dock-backends-manager.h"  // myBackendsParam.fSubDockSizeRatio
-#include "cairo-dock-X-utilities.h"
+#include "cairo-dock-X-utilities.h"  // cairo_dock_set_xicon_geometry
 #include "cairo-dock-log.h"
 #include "cairo-dock-application-facility.h"  // cairo_dock_detach_appli
 #include "cairo-dock-dialog-manager.h"  // cairo_dock_replace_all_dialogs
-#include "cairo-dock-keyfile-utilities.h"
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-notifications.h"
-#include "cairo-dock-class-manager.h"
+#include "cairo-dock-class-manager.h"   // cairo_dock_get_class_subdock
 #include "cairo-dock-animations.h"
 #include "cairo-dock-container.h"
-#include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-themes-manager.h"
-#include "cairo-dock-gui-manager.h"
 #include "cairo-dock-dock-facility.h"
-#include "cairo-dock-desktop-file-factory.h"
-#include "cairo-dock-draw-opengl.h"
-#include "cairo-dock-opengl.h"
-#include "cairo-dock-data-renderer.h"
+#include "cairo-dock-draw-opengl.h"  // for the redirected texture
+#include "cairo-dock-data-renderer.h"  // cairo_dock_reload_data_renderer_on_icon
+
 #include "cairo-dock-dock-factory.h"
 
 extern gchar *g_cCurrentLaunchersPath;
@@ -404,7 +382,7 @@ static gboolean _cairo_dock_dock_animation_loop (CairoContainer *pContainer)
 			icon->iAnimationState = CAIRO_DOCK_STATE_REST;
 			if (icon->bIsDemandingAttention)
 			{
-				icon->bIsDemandingAttention = FALSE;
+				icon->bIsDemandingAttention = FALSE;  // the attention animation has finished by itself after the time it was planned for.
 				bNoMoreDemandingAttention = TRUE;
 			}
 		}
@@ -513,38 +491,32 @@ static void _setup_menu (CairoContainer *pContainer, G_GNUC_UNUSED Icon *pIcon,
 
 CairoDock *cairo_dock_new_dock (void)
 {
-	//\__________________ On cree un dock.
-	CairoDock *pDock = g_new0 (CairoDock, 1);
-	pDock->container.iType = CAIRO_DOCK_TYPE_DOCK;
+	//\__________________ create a dock.
+	CairoDock * pDock = gldi_container_new (CairoDock, &myDocksMgr, CAIRO_DOCK_TYPE_DOCK);
+	
+	//\__________________ initialize its parameters (it's a root dock by default)
+	pDock->container.iface.animation_loop = _cairo_dock_dock_animation_loop;
+	pDock->container.iface.setup_menu = _setup_menu;
 	
-	pDock->iRefCount = 0;  // c'est un dock racine par defaut.
 	pDock->iAvoidingMouseIconType = -1;
 	pDock->fFlatDockWidth = - myIconsParam.iIconGap;
-	///pDock->container.iMouseX = -1; // utile ?
-	///pDock->container.iMouseY = -1;
 	pDock->fMagnitudeMax = 1.;
 	pDock->fPostHideOffset = 1.;
 	pDock->iInputState = CAIRO_DOCK_INPUT_AT_REST;  // le dock est cree au repos. La zone d'input sera mis en place lors du configure.
 	
-	pDock->container.iface.animation_loop = _cairo_dock_dock_animation_loop;
-	pDock->container.iface.setup_menu = _setup_menu;
-	
-	//\__________________ On cree la fenetre GTK.
-	GtkWidget *pWindow = cairo_dock_init_container (CAIRO_CONTAINER (pDock));
-	///cairo_dock_install_notifications_on_object (pDock, NB_NOTIFICATIONS_DOCKS);
-	gldi_object_set_manager (GLDI_OBJECT (pDock), GLDI_MANAGER (&myDocksMgr));
+	//\__________________ set up its window
+	GtkWidget *pWindow = pDock->container.pWidget;
 	gtk_container_set_border_width (GTK_CONTAINER (pWindow), 0);
 	gtk_window_set_gravity (GTK_WINDOW (pWindow), GDK_GRAVITY_STATIC);
 	gtk_window_set_type_hint (GTK_WINDOW (pWindow), GDK_WINDOW_TYPE_HINT_DOCK);
 	gtk_window_set_title (GTK_WINDOW (pWindow), "cairo-dock");
 	
-	
 	cairo_dock_register_notification_on_object (pDock,
 		NOTIFICATION_RENDER,
 		(CairoDockNotificationFunc) cairo_dock_render_dock_notification,
 		CAIRO_DOCK_RUN_FIRST, NULL);
 	
-	//\__________________ On connecte les evenements a la fenetre.
+	//\__________________ connect to events.
 	gtk_widget_add_events (pWindow,
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_SCROLL_MASK |
 		GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
@@ -684,8 +656,7 @@ void cairo_dock_make_sub_dock (CairoDock *pDock, CairoDock *pParentDock, const g
 	//\__________________ set the orientation relatively to the parent dock
 	pDock->container.bIsHorizontal = pParentDock->container.bIsHorizontal;
 	pDock->container.bDirectionUp = pParentDock->container.bDirectionUp;
-	pDock->iScreenOffsetX = pParentDock->iScreenOffsetX;
-	pDock->iScreenOffsetY = pParentDock->iScreenOffsetY;
+	pDock->iNumScreen = pParentDock->iNumScreen;
 	
 	//\__________________ set a renderer
 	cairo_dock_set_renderer (pDock, cRendererName);
@@ -701,7 +672,8 @@ void cairo_dock_make_sub_dock (CairoDock *pDock, CairoDock *pParentDock, const g
 	for (ic = pDock->icons; ic != NULL; ic = ic->next)
 	{
 		icon = ic->data;
-		icon->fWidth = icon->fHeight = icon->iImageWidth = icon->iImageHeight = 0;  // no request
+		cairo_dock_icon_set_requested_size (icon, 0, 0);  // no request
+		icon->fWidth = icon->fHeight = 0;  /// useful ?...
 		cairo_dock_set_icon_size_in_dock (pDock, icon);
 		pDock->fFlatDockWidth += icon->fWidth + myIconsParam.iIconGap;
 	}
@@ -738,6 +710,10 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 		cd_warning ("This icon (%s) is already inside a container !", icon->cName);
 	}
 
+	// maybe the icon was detached before and then cParentDockName is NULL
+	if (icon->cParentDockName == NULL)
+		icon->cParentDockName = g_strdup (cairo_dock_search_dock_name (pDock));
+
 	//\______________ check if a separator is needed (ie, if the group of the new icon (not its order) is new).
 	gboolean bSeparatorNeeded = FALSE;
 	if (bInsertSeparator && ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))
@@ -768,11 +744,11 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	cairo_dock_set_icon_container (icon, pDock);
 	
 	//\______________ set the icon size, now that it's inside a container.
-	int wi = icon->iImageWidth, hi = icon->iImageHeight;
+	int wi = icon->image.iWidth, hi = icon->image.iHeight;
 	cairo_dock_set_icon_size_in_dock (pDock, icon);
 	
-	if (wi != icon->iImageWidth || hi != icon->iImageHeight  // if size has changed, reload the buffers
-	|| (! icon->pIconBuffer && ! icon->iIconTexture))  // might happen, for instance if the icon is a launcher pinned on a desktop and was detached before being loaded.
+	if (wi != cairo_dock_icon_get_allocated_width (icon) || hi != cairo_dock_icon_get_allocated_height (icon)  // if size has changed, reload the buffers
+	|| (! icon->image.pSurface && ! icon->image.iTexture))  // might happen, for instance if the icon is a launcher pinned on a desktop and was detached before being loaded.
 		cairo_dock_trigger_load_icon_buffers (icon);
 	
 	pDock->fFlatDockWidth += myIconsParam.iIconGap + icon->fWidth;
@@ -823,7 +799,7 @@ void cairo_dock_insert_icon_in_dock_full (Icon *icon, CairoDock *pDock, gboolean
 	}
 	
 	if (icon->pSubDock != NULL)
-		cairo_dock_synchronize_one_sub_dock_orientation (icon->pSubDock, pDock, TRUE);
+		cairo_dock_synchronize_one_sub_dock_orientation (icon->pSubDock, pDock, FALSE);
 	
 	//\______________ Notify everybody.
 	cairo_dock_notify_on_object (pDock, NOTIFICATION_INSERT_ICON, icon, pDock);
@@ -874,9 +850,6 @@ gboolean cairo_dock_detach_icon_from_dock_full (Icon *icon, CairoDock *pDock, gb
 		return FALSE;
 	
 	cd_message ("%s (%s)", __func__, icon->cName);
-	g_free (icon->cParentDockName);
-	icon->cParentDockName = NULL;
-	cairo_dock_set_icon_container (icon, NULL);
 	
 	//\___________________ On stoppe ses animations.
 	cairo_dock_stop_icon_animation (icon);
@@ -956,6 +929,11 @@ gboolean cairo_dock_detach_icon_from_dock_full (Icon *icon, CairoDock *pDock, gb
 	icon->fInsertRemoveFactor = 0.;
 	cairo_dock_notify_on_object (pDock, NOTIFICATION_REMOVE_ICON, icon, pDock);
 	
+	//\___________________ unset the container, now that it's completely detached from it.
+	g_free (icon->cParentDockName);
+	icon->cParentDockName = NULL;
+	cairo_dock_set_icon_container (icon, NULL);
+	
 	return TRUE;
 }
 void cairo_dock_remove_icon_from_dock_full (CairoDock *pDock, Icon *icon, gboolean bCheckUnusedSeparator)
@@ -967,12 +945,7 @@ void cairo_dock_remove_icon_from_dock_full (CairoDock *pDock, Icon *icon, gboole
 		cairo_dock_detach_icon_from_dock_full (icon, pDock, bCheckUnusedSeparator);  // on le fait maintenant, pour que l'icone ait son type correct, et ne soit pas confondue avec un separateur
 	
 	//\___________________ On supprime l'icone du theme courant.
-	if (icon->iface.on_delete)
-	{
-		gboolean r = icon->iface.on_delete (icon);
-		if (r)
-			cairo_dock_mark_current_theme_as_modified (TRUE);
-	}
+	cairo_dock_delete_icon_from_current_theme (icon);
 }
 
 
@@ -1055,8 +1028,6 @@ Icon *cairo_dock_add_new_launcher_by_uri_or_type (const gchar *cExternDesktopFil
 	Icon *pNewIcon = NULL;
 	if (cNewDesktopFileName != NULL)
 	{
-		cairo_dock_mark_current_theme_as_modified (TRUE);
-
 		pNewIcon = cairo_dock_create_icon_from_desktop_file (cNewDesktopFileName);
 		g_free (cNewDesktopFileName);
 
@@ -1089,8 +1060,7 @@ void cairo_dock_remove_icons_from_dock (CairoDock *pDock, CairoDock *pReceivingD
 
 		if (pReceivingDock == NULL || cReceivingDockName == NULL)  // alors on les jete.
 		{
-			if (icon->iface.on_delete)
-				icon->iface.on_delete (icon);  // efface le .desktop / ecrit les modules actifs.
+			cairo_dock_delete_icon_from_current_theme (icon);
 			
 			if (CAIRO_DOCK_IS_APPLET (icon))
 			{
@@ -1144,8 +1114,7 @@ void cairo_dock_reload_buffers_in_dock (CairoDock *pDock, gboolean bRecursive, g
 		{
 			if (bUpdateIconSize)
 			{
-				icon->fWidth = icon->fHeight = 0;  // no request
-				icon->iImageWidth = icon->iImageHeight = 0;
+				cairo_dock_icon_set_requested_size (icon, 0, 0);
 				cairo_dock_set_icon_size_in_dock (pDock, icon);
 			}
 			cairo_dock_trigger_load_icon_buffers (icon);
@@ -1167,7 +1136,7 @@ void cairo_dock_reload_buffers_in_dock (CairoDock *pDock, gboolean bRecursive, g
 	{
 		cairo_dock_update_dock_size (pDock);
 		cairo_dock_calculate_dock_icons (pDock);
-
+		
 		cairo_dock_move_resize_dock (pDock);
 		if (pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE)  // la position/taille a change, il faut refaire la reservation.
 			cairo_dock_reserve_space_for_dock (pDock, TRUE);
@@ -1178,13 +1147,17 @@ void cairo_dock_reload_buffers_in_dock (CairoDock *pDock, gboolean bRecursive, g
 
 void cairo_dock_set_icon_size_in_dock (CairoDock *pDock, Icon *icon)
 {
-	if (pDock->pRenderer && pDock->pRenderer->set_icon_size)
+	if (pDock->pRenderer && pDock->pRenderer->set_icon_size)  // the view wants to decide the icons size.
 	{
 		pDock->pRenderer->set_icon_size (icon, pDock);
 	}
-	else
+	else  // generic method: icon extent = base size * max zoom
 	{
-		int wi, hi;
+		int wi, hi;  // icon size (icon size displayed at rest, as defined in the config)
+		int wa, ha;  // allocated size (surface/texture).
+		gboolean bIsHorizontal = (pDock->container.bIsHorizontal || (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && myIconsParam.bRevolveSeparator));
+		
+		// get the displayed icon size as defined in the config
 		if (! pDock->bGlobalIconSize && pDock->iIconSize != 0)
 		{
 			wi = hi = pDock->iIconSize;
@@ -1194,56 +1167,56 @@ void cairo_dock_set_icon_size_in_dock (CairoDock *pDock, Icon *icon)
 			wi = myIconsParam.iIconWidth;
 			hi = myIconsParam.iIconHeight;
 		}
-		//g_print (" size: %d => %dx%d\n", pDock->iIconSize, wi, hi);
-		double fMaxScale = cairo_dock_get_max_scale (pDock);
 		
-		// set the visible size at rest.
-		if (CAIRO_DOCK_ICON_TYPE_IS_APPLET (icon))  // for applets, consider (fWidth,fHeight) as a requested size, if not 0.
+		if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))  // separators have their own size.
 		{
-			//g_print ("%s (%s, %.1fx%.1f\n", __func__, icon->pModuleInstance->pModule->pVisitCard->cModuleName, icon->fWidth, icon->fHeight);
-			if (icon->iImageWidth != 0)
-			{
-				if (pDock->container.bIsHorizontal)
-					icon->fWidth = icon->iImageWidth / fMaxScale;
-				else
-					icon->fHeight = icon->iImageWidth / fMaxScale;
-			}
-			if (icon->iImageHeight != 0)
-			{
-				if (pDock->container.bIsHorizontal)
-					icon->fHeight = icon->iImageHeight / fMaxScale;
-				else
-					icon->fWidth = icon->iImageHeight / fMaxScale;
-			}
-			if (icon->fWidth == 0)
-				icon->fWidth = wi;
-			if (icon->fHeight == 0 || icon->fHeight > hi)
-				icon->fHeight = hi;
-		}
-		else if (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon))  // separators have their own size.
-		{
-			icon->fWidth = myIconsParam.iSeparatorWidth;
-			icon->fHeight = MIN (myIconsParam.iSeparatorHeight, hi);
-		}
-		else  // any other icon use the global size
-		{
-			icon->fWidth = wi;
-			icon->fHeight = hi;
+			wi = myIconsParam.iSeparatorWidth;
+			hi = MIN (myIconsParam.iSeparatorHeight, hi);
 		}
 		
-		// texture size can be deduced then.
-		if (pDock->container.bIsHorizontal
-		|| (CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (icon) && myIconsParam.bRevolveSeparator))
+		// take into account the requested displayed size if any
+		int wir = cairo_dock_icon_get_requested_display_width (icon);
+		if (wir != 0)
+			wi = wir;
+		int hir = cairo_dock_icon_get_requested_display_height (icon);
+		if (hir != 0)
+			hi = MIN (hir, hi);  // limit the icon height to the default height.
+		
+		// get the requested size if any
+		wa = cairo_dock_icon_get_requested_width (icon);
+		ha = cairo_dock_icon_get_requested_height (icon);
+		
+		// compute the missing size (allocated or displayed).
+		double fMaxScale = 1 + myIconsParam.fAmplitude;
+		if (wa == 0)
 		{
-			icon->iImageWidth = icon->fWidth * fMaxScale;
-			icon->iImageHeight = icon->fHeight * fMaxScale;
+			wa = (bIsHorizontal ? wi : hi) * fMaxScale;
 		}
 		else
 		{
-			icon->iImageWidth = icon->fHeight * fMaxScale;
-			icon->iImageHeight = icon->fWidth * fMaxScale;
+			if (bIsHorizontal)
+				wi = wa / fMaxScale;
+			else
+				hi = wa / fMaxScale;
 		}
+		if (ha == 0)
+		{
+			ha = (bIsHorizontal ? hi : wi) * fMaxScale;
+		}
+		else
+		{
+			if (bIsHorizontal)
+				hi = ha / fMaxScale;
+			else
+				wi = ha / fMaxScale;
+		}
+		
+		// set both allocated and displayed size 
+		cairo_dock_icon_set_allocated_size (icon, wa, ha);
+		icon->fWidth = wi;
+		icon->fHeight = hi;
 	}
+	// take into account the current ratio
 	icon->fWidth *= pDock->container.fRatio;
 	icon->fHeight *= pDock->container.fRatio;
 }
