@@ -18,36 +18,19 @@
 */
 
 #include <math.h>
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <iconv.h>
+#include <GL/gl.h>
+#include <gdk/gdkx.h>  // gdk_x11_get_default_xdisplay
 
-#include <glib/gstdio.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkx.h>
-
-#include <cairo.h>
-#include <pango/pango.h>
-
-
-#include <X11/extensions/Xrender.h>
-#include <GL/glx.h>
-#include <GL/glxext.h>
-
-#include "cairo-dock-icon-factory.h"
 #include "cairo-dock-icon-facility.h"
-#include "cairo-dock-draw.h"
-#include "cairo-dock-notifications.h"
-#include "cairo-dock-backends-manager.h"
+#include "cairo-dock-notifications.h"  // for NOTIFICATION_RENDER_ICON
 #include "cairo-dock-log.h"
-#include "cairo-dock-container.h"
-#include "cairo-dock-dock-facility.h"
+#include "cairo-dock-dock-facility.h"  // cairo_dock_get_first_drawn_element_linear
 #include "cairo-dock-applications-manager.h"  // myTaskbarParam.fVisibleAppliAlpha
 #include "cairo-dock-dock-manager.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-overlay.h"
 #include "cairo-dock-opengl-path.h"
+
 #include "cairo-dock-draw-opengl.h"
 
 #include "texture-gradation.h"
@@ -58,7 +41,6 @@ extern GLuint g_pGradationTexture[2];
 
 extern CairoContainer *g_pPrimaryContainer;
 
-extern CairoDockImageBuffer g_pIconBackgroundImageBuffer;
 extern CairoDockImageBuffer g_pVisibleZoneBuffer;
 
 extern gboolean g_bUseOpenGL;
@@ -184,7 +166,7 @@ void cairo_dock_draw_icon_reflect_opengl (Icon *pIcon, CairoDock *pDock)
 		}
 		
 		glEnable(GL_TEXTURE_2D);
-		glBindTexture(GL_TEXTURE_2D, pIcon->iIconTexture);
+		glBindTexture(GL_TEXTURE_2D, pIcon->image.iTexture);
 		glEnable(GL_BLEND);
 		_cairo_dock_set_blend_alpha ();
 		glTexEnvi (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
@@ -251,12 +233,12 @@ void cairo_dock_draw_icon_opengl (Icon *pIcon, CairoDock *pDock)
 	
 	_cairo_dock_enable_texture ();
 	if (pIcon->fAlpha == 1)
-		_cairo_dock_set_blend_over ();
+		_cairo_dock_set_blend_pbuffer ();
 	else
 		_cairo_dock_set_blend_alpha ();
-	
-	_cairo_dock_apply_texture_at_size_with_alpha (pIcon->iIconTexture, fSizeX, fSizeY, pIcon->fAlpha);
-	
+	_cairo_dock_apply_texture_at_size_with_alpha (pIcon->image.iTexture, fSizeX, fSizeY, pIcon->fAlpha);
+	//if (g_strcmp0 (pIcon->cName, "Calculatrice") == 0)
+		//g_print ("%s: %.2f\n", pIcon->cName, pIcon->fAlpha);
 	//\_____________________ On dessine son reflet.
 	cairo_dock_draw_icon_reflect_opengl (pIcon, pDock);
 	
@@ -321,7 +303,7 @@ void cairo_dock_translate_on_icon_opengl (Icon *icon, CairoContainer *pContainer
 
 void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDockMagnitude, gboolean bUseText)
 {
-	if (icon->iIconTexture == 0)
+	if (icon->image.iTexture == 0)
 		return ;
 	double fRatio = pDock->container.fRatio;
 	
@@ -418,10 +400,10 @@ void cairo_dock_render_one_icon_opengl (Icon *icon, CairoDock *pDock, double fDo
 		glLoadIdentity ();
 		
 		_cairo_dock_enable_texture ();
-		_cairo_dock_set_blend_alpha ();
+		_cairo_dock_set_blend_alpha ();  // not good with a transparent background :-/
 		
 		double fMagnitude;
-		if (myIconsParam.bLabelForPointedIconOnly ||pDock->fMagnitudeMax == 0.)
+		if (myIconsParam.bLabelForPointedIconOnly || pDock->fMagnitudeMax == 0. || myIconsParam.fAmplitude == 0.)
 		{
 			fMagnitude = fDockMagnitude;  // (icon->fScale - 1) / myIconsParam.fAmplitude / sin (icon->fPhase);  // sin (phi ) != 0 puisque fScale > 1.
 		}
@@ -590,7 +572,7 @@ void cairo_dock_render_hidden_dock_opengl (CairoDock *pDock)
 	GList *ic = pFirstDrawnElement;
 	double pHiddenBgColor[4];
 	const double r = 4; // corner radius of the background
-	const double gap = 3;  // gap to the screen
+	const double gap = 2;  // gap to the screen
 	double dw = (myIconsParam.iIconGap > 2 ? 2 : 0);  // 1px margin around the icons for a better readability (only if icons won't be stuck togather then).
 	double w, h;
 	_cairo_dock_set_blend_alpha ();
@@ -645,7 +627,6 @@ void cairo_dock_render_hidden_dock_opengl (CairoDock *pDock)
 }
 
 
-
 GLuint cairo_dock_create_texture_from_surface (cairo_surface_t *pImageSurface)
 {
 	if (! g_bUseOpenGL || pImageSurface == NULL)
@@ -681,7 +662,7 @@ GLuint cairo_dock_create_texture_from_surface (cairo_surface_t *pImageSurface)
 	
 	_cairo_dock_enable_texture ();
 	_cairo_dock_set_blend_source ();
-	glColor4f (1., 1., 1., 1.);
+	_cairo_dock_set_alpha (1.);  // full white
 	glGenTextures (1, &iTexture);
 	//g_print ("+ texture %d generee (%p, %dx%d)\n", iTexture, cairo_image_surface_get_data (pImageSurface), w, h);
 	glBindTexture (GL_TEXTURE_2D, iTexture);
@@ -787,7 +768,6 @@ GLuint cairo_dock_create_texture_from_image_full (const gchar *cImageFile, doubl
 	else
 		cImagePath = cairo_dock_search_image_s_path (cImageFile);
 	
-	cairo_t *pCairoContext = cairo_dock_create_drawing_context_generic (g_pPrimaryContainer);
 	cairo_surface_t *pSurface = cairo_dock_create_surface_from_image (cImagePath,
 		1.,
 		0., 0.,
@@ -796,7 +776,6 @@ GLuint cairo_dock_create_texture_from_image_full (const gchar *cImageFile, doubl
 		&fHeight,
 		NULL, NULL);
 	//cd_debug ("texture genere (%x, %.2fx%.2f)", pSurface, fWidth, fHeight);
-	cairo_destroy (pCairoContext);
 	
 	if (fImageWidth != NULL)
 		*fImageWidth = fWidth;
@@ -812,17 +791,17 @@ GLuint cairo_dock_create_texture_from_image_full (const gchar *cImageFile, doubl
 
 void cairo_dock_update_icon_texture (Icon *pIcon)
 {
-	if (pIcon != NULL && pIcon->pIconBuffer != NULL)
+	if (pIcon != NULL && pIcon->image.pSurface != NULL)
 	{
 		_cairo_dock_enable_texture ();
 		_cairo_dock_set_blend_source ();
-		glColor4f (1., 1., 1., 1.);
+		_cairo_dock_set_alpha (1.);  // full white
 		
-		if (pIcon->iIconTexture == 0)
-			glGenTextures (1, &pIcon->iIconTexture);
-		int w = cairo_image_surface_get_width (pIcon->pIconBuffer);
-		int h = cairo_image_surface_get_height (pIcon->pIconBuffer);
-		glBindTexture (GL_TEXTURE_2D, pIcon->iIconTexture);
+		if (pIcon->image.iTexture == 0)
+			glGenTextures (1, &pIcon->image.iTexture);
+		int w = cairo_image_surface_get_width (pIcon->image.pSurface);
+		int h = cairo_image_surface_get_height (pIcon->image.pSurface);
+		glBindTexture (GL_TEXTURE_2D, pIcon->image.iTexture);
 		
 		glTexParameteri (GL_TEXTURE_2D,
 			GL_TEXTURE_MIN_FILTER,
@@ -838,7 +817,7 @@ void cairo_dock_update_icon_texture (Icon *pIcon)
 				h,
 				GL_BGRA,
 				GL_UNSIGNED_BYTE,
-				cairo_image_surface_get_data (pIcon->pIconBuffer));
+				cairo_image_surface_get_data (pIcon->image.pSurface));
 		else
 			glTexImage2D (GL_TEXTURE_2D,
 				0,
@@ -848,7 +827,7 @@ void cairo_dock_update_icon_texture (Icon *pIcon)
 				0,
 				GL_BGRA,  // GL_ALPHA / GL_BGRA
 				GL_UNSIGNED_BYTE,
-				cairo_image_surface_get_data (pIcon->pIconBuffer));
+				cairo_image_surface_get_data (pIcon->image.pSurface));
 		glDisable (GL_TEXTURE_2D);
 	}
 }
@@ -862,7 +841,7 @@ void cairo_dock_draw_texture_with_alpha (GLuint iTexture, int iWidth, int iHeigh
 		//~ _cairo_dock_set_blend_over ();
 	//~ else
 		///_cairo_dock_set_blend_alpha ();
-		_cairo_dock_set_blend_over ();
+	_cairo_dock_set_blend_over ();  // gives the best result, at least with fAlpha=1
 	
 	_cairo_dock_apply_texture_at_size_with_alpha (iTexture, iWidth, iHeight, fAlpha);
 	
@@ -879,7 +858,7 @@ void cairo_dock_apply_icon_texture_at_current_size (Icon *pIcon, CairoContainer
 	double fSizeX, fSizeY;
 	cairo_dock_get_current_icon_size (pIcon, pContainer, &fSizeX, &fSizeY);
 	
-	_cairo_dock_apply_texture_at_size (pIcon->iIconTexture, fSizeX, fSizeY);
+	_cairo_dock_apply_texture_at_size (pIcon->image.iTexture, fSizeX, fSizeY);
 }
 
 void cairo_dock_draw_icon_texture (Icon *pIcon, CairoContainer *pContainer)
@@ -887,7 +866,7 @@ void cairo_dock_draw_icon_texture (Icon *pIcon, CairoContainer *pContainer)
 	double fSizeX, fSizeY;
 	cairo_dock_get_current_icon_size (pIcon, pContainer, &fSizeX, &fSizeY);
 	
-	cairo_dock_draw_texture_with_alpha (pIcon->iIconTexture,
+	cairo_dock_draw_texture_with_alpha (pIcon->image.iTexture,
 		fSizeX,
 		fSizeY,
 		pIcon->fAlpha);
@@ -948,8 +927,8 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 		GLuint iOriginalTexture;
 		if (pIcon->bIsHidden)
 		{
-			iOriginalTexture = pIcon->iIconTexture;
-			pIcon->iIconTexture = cairo_dock_create_texture_from_surface (pIcon->pIconBuffer);
+			iOriginalTexture = pIcon->image.iTexture;
+			pIcon->image.iTexture = cairo_dock_create_texture_from_surface (pIcon->image.pSurface);
 			/// Using FBOs copies the texture data (pixels) within VRAM only:
 			/// - setup & bind FBO
 			/// - setup destination texture (using glTexImage() w/ pixels = 0)
@@ -959,7 +938,7 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 		}
 		else
 		{
-			iOriginalTexture = cairo_dock_create_texture_from_surface (pIcon->pIconBuffer);
+			iOriginalTexture = cairo_dock_create_texture_from_surface (pIcon->image.pSurface);
 		}
 		
 		cairo_dock_set_transition_on_icon (pIcon, pContainer,
@@ -975,7 +954,7 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 	{
 		if (!cairo_dock_begin_draw_icon (pIcon, pContainer, 2))
 			return ;
-		_draw_icon_bent_backwards (pIcon, pContainer, pIcon->iIconTexture, 1.);
+		_draw_icon_bent_backwards (pIcon, pContainer, pIcon->image.iTexture, 1.);
 		cairo_dock_end_draw_icon (pIcon, pContainer);
 	}
 }
@@ -988,8 +967,8 @@ void cairo_dock_draw_hidden_appli_icon (Icon *pIcon, CairoContainer *pContainer,
 // Bind redirected window to texture:
 GLuint cairo_dock_texture_from_pixmap (Window Xid, Pixmap iBackingPixmap)
 {
-	///if (!g_bEasterEggs)
-	///	return 0;  /// ca ne marche pas. :-(
+	if (!g_bEasterEggs)
+		return 0;  /// works for some windows (gnome-terminal) but not for all ... still need to figure why.
 	
 	if (!iBackingPixmap || ! g_openglConfig.bTextureFromPixmapAvailable)
 		return 0;
