@@ -101,7 +101,7 @@ void cairo_dock_load_image_buffer_full (CairoDockImageBuffer *pImage, const gcha
 */
 void cairo_dock_load_image_buffer_from_surface (CairoDockImageBuffer *pImage, cairo_surface_t *pSurface, int iWidth, int iHeight);
 
-void cairo_dock_load_image_buffer_from_texture (CairoDockImageBuffer *pImage, GLuint iTexture);
+void cairo_dock_load_image_buffer_from_texture (CairoDockImageBuffer *pImage, GLuint iTexture, int iWidth, int iHeight);
 
 /** Create and load an image into an ImageBuffer. If the image is given by its sole name, it is taken in the root folder of the current theme.
 *@param cImageFile name of a file
@@ -116,8 +116,12 @@ CairoDockImageBuffer *cairo_dock_create_image_buffer (const gchar *cImageFile, i
 
 void cairo_dock_image_buffer_next_frame (CairoDockImageBuffer *pImage);
 
+gboolean cairo_dock_image_buffer_next_frame_no_loop (CairoDockImageBuffer *pImage);
+
 #define cairo_dock_image_buffer_set_timelength(pImage, fTimeLength) (pImage)->fDeltaFrame = ((pImage)->iNbFrames != 0 ? (double)fTimeLength / (pImage)->iNbFrames : 1)
 
+#define cairo_dock_image_buffer_rewind(pImage) gettimeofday (&pImage->time, NULL)
+
 /** Reset an ImageBuffer's ressources. It can be used to load another image then.
 *@param pImage an ImageBuffer.
 */
@@ -128,14 +132,14 @@ void cairo_dock_unload_image_buffer (CairoDockImageBuffer *pImage);
 void cairo_dock_free_image_buffer (CairoDockImageBuffer *pImage);
 
 
-/** Draw an ImageBuffer with an offset on a Cairo context.
+/** Draw an ImageBuffer with an offset on a Cairo context, at the size it was loaded.
 *@param pImage an ImageBuffer.
 *@param pCairoContext the current cairo context.
 *@param x horizontal offset.
 *@param y vertical offset.
 *@param fAlpha transparency (in [0;1])
 */
-void cairo_dock_apply_image_buffer_surface_with_offset (CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha);
+void cairo_dock_apply_image_buffer_surface_with_offset (const CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha);
 
 /** Draw an ImageBuffer on a cairo context.
 *@param pImage an ImageBuffer.
@@ -143,22 +147,67 @@ void cairo_dock_apply_image_buffer_surface_with_offset (CairoDockImageBuffer *pI
 */
 #define cairo_dock_apply_image_buffer_surface(pImage, pCairoContext) cairo_dock_apply_image_buffer_surface_with_offset (pImage, pCairoContext, 0., 0., 1.)
 
-/** Draw an ImageBuffer with an offset on the current OpenGL context.
+/** Draw an ImageBuffer with an offset on the current OpenGL context, at the size it was loaded.
 *@param pImage an ImageBuffer.
 *@param x horizontal offset.
 *@param y vertical offset.
 */
-void cairo_dock_apply_image_buffer_texture_with_offset (CairoDockImageBuffer *pImage, double x, double y);
+void cairo_dock_apply_image_buffer_texture_with_offset (const CairoDockImageBuffer *pImage, double x, double y);
 
 /** Draw an ImageBuffer on the current OpenGL context.
 *@param pImage an ImageBuffer.
 */
 #define cairo_dock_apply_image_buffer_texture(pImage) cairo_dock_apply_image_buffer_texture_with_offset (pImage, 0., 0.)
 
-void cairo_dock_apply_image_buffer_surface_with_offset_and_limit (CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha, int iMaxWidth);
+/** Draw an ImageBuffer with an offset on a Cairo context, at a given size.
+*@param pImage an ImageBuffer.
+*@param pCairoContext the current cairo context.
+*@param w requested width
+*@param h requested height
+*@param x horizontal offset.
+*@param y vertical offset.
+*@param fAlpha transparency (in [0;1])
+*/
+void cairo_dock_apply_image_buffer_surface_at_size (const CairoDockImageBuffer *pImage, cairo_t *pCairoContext, int w, int h, double x, double y, double fAlpha);
 
-void cairo_dock_apply_image_buffer_texture_with_limit (CairoDockImageBuffer *pImage, double fAlpha, int iMaxWidth);
+/** Draw an ImageBuffer on the current OpenGL context at a given size.
+*@param pImage an ImageBuffer.
+*@param w requested width
+*@param h requested height
+*@param x horizontal offset.
+*@param y vertical offset.
+*/
+void cairo_dock_apply_image_buffer_texture_at_size (const CairoDockImageBuffer *pImage, int w, int h, double x, double y);
 
 
+void cairo_dock_apply_image_buffer_surface_with_offset_and_limit (const CairoDockImageBuffer *pImage, cairo_t *pCairoContext, double x, double y, double fAlpha, int iMaxWidth);
+
+void cairo_dock_apply_image_buffer_texture_with_limit (const CairoDockImageBuffer *pImage, double fAlpha, int iMaxWidth);
+
+
+  ///////////////////////
+ // RENDER TO TEXTURE //
+///////////////////////
+
+/** Create an FBO to render the icons inside a dock.
+*/
+void cairo_dock_create_icon_fbo (void);
+/** Destroy the icons FBO.
+*/
+void cairo_dock_destroy_icon_fbo (void);
+
+cairo_t *cairo_dock_begin_draw_image_buffer_cairo (CairoDockImageBuffer *pImage, gint iRenderingMode, cairo_t *pCairoContext);
+
+void cairo_dock_end_draw_image_buffer_cairo (CairoDockImageBuffer *pImage);
+
+gboolean cairo_dock_begin_draw_image_buffer_opengl (CairoDockImageBuffer *pImage, CairoContainer *pContainer, gint iRenderingMode);
+
+void cairo_dock_end_draw_image_buffer_opengl (CairoDockImageBuffer *pImage, CairoContainer *pContainer);
+
+void cairo_dock_image_buffer_update_texture (CairoDockImageBuffer *pImage);
+
+
+GdkPixbuf *cairo_dock_image_buffer_to_pixbuf (CairoDockImageBuffer *pImage, int iWidth, int iHeight);
+
 G_END_DECLS
 #endif
