@@ -36,7 +36,6 @@
 #include "cairo-dock-log.h"
 #include "cairo-dock-applet-manager.h"
 #include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
-#include "cairo-dock-X-manager.h"  // g_desktopGeometry
 #include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-dialog-manager.h"  // cairo_dock_show_temporary_dialog_with_icon
@@ -83,7 +82,7 @@ static gboolean _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GErr
 		return ;
 	}
 	pCairoDockModule->pModule = module;*/
-	pCairoDockModule->handle = dlopen (pCairoDockModule->cSoFilePath, RTLD_LAZY | RTLD_LOCAL | RTLD_DEEPBIND);
+	pCairoDockModule->handle = dlopen (pCairoDockModule->cSoFilePath, RTLD_LAZY | RTLD_LOCAL);
 	if (! pCairoDockModule->handle)
 	{
 		g_set_error (erreur, 1, 1, "while opening module '%s' : (%s)", pCairoDockModule->cSoFilePath, dlerror ());
@@ -132,7 +131,7 @@ static gboolean _cairo_dock_open_module (CairoDockModule *pCairoDockModule, GErr
 
 CairoDockModule *cairo_dock_new_module (const gchar *cSoFilePath, GError **erreur)
 {
-	CairoDockModule *pCairoDockModule = g_new0 (CairoDockModule, 1);
+	CairoDockModule *pCairoDockModule = gldi_object_new (CairoDockModule, &myModulesMgr);
 	
 	if (cSoFilePath != NULL)
 	{
@@ -161,6 +160,8 @@ void cairo_dock_free_module (CairoDockModule *module)
 		cd_debug ("%s (%s)", __func__, module->pVisitCard->cModuleName);
 		cairo_dock_deactivate_module (module);
 	}
+	
+	cairo_dock_notify_on_object (module, NOTIFICATION_DESTROY, module);
 	_cairo_dock_close_module (module);
 
 	g_free (module->cSoFilePath);
@@ -253,14 +254,6 @@ GKeyFile *cairo_dock_pre_read_module_instance_config (CairoDockModuleInstance *p
 	{
 		gboolean bUnused;
 		cairo_dock_get_size_key_value_helper (pKeyFile, "Icon", "icon ", bUnused, pMinimalConfig->iDesiredIconWidth, pMinimalConfig->iDesiredIconHeight);  // for a dock, if 0, will just get the default size; for a desklet, unused.
-		/**if (pMinimalConfig->iDesiredIconWidth == 0)
-			pMinimalConfig->iDesiredIconWidth = myIconsParam.iIconWidth;
-		if (pMinimalConfig->iDesiredIconWidth == 0)
-			pMinimalConfig->iDesiredIconWidth = 48;
-		if (pMinimalConfig->iDesiredIconHeight == 0)
-			pMinimalConfig->iDesiredIconHeight = myIconsParam.iIconHeight;
-		if (pMinimalConfig->iDesiredIconHeight == 0)
-			pMinimalConfig->iDesiredIconHeight = 48;*/
 		
 		pMinimalConfig->cLabel = cairo_dock_get_string_key_value (pKeyFile, "Icon", "name", NULL, NULL, NULL, NULL);
 		if (pMinimalConfig->cLabel == NULL && !pInstance->pModule->pVisitCard->bAllowEmptyTitle)
@@ -409,6 +402,9 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 	
 	//\____________________ On cree une instance du module.
 	CairoDockModuleInstance *pInstance = g_malloc0 (sizeof (CairoDockModuleInstance) + pModule->pVisitCard->iSizeOfConfig + pModule->pVisitCard->iSizeOfData);  // we allocate everything at once, since config and data will anyway live as long as the instance itself.
+	GLDI_OBJECT(pInstance)->ref = 1;
+	gldi_object_set_manager (GLDI_OBJECT (pInstance), GLDI_MANAGER (&myModulesMgr));
+	
 	pInstance->pModule = pModule;
 	pInstance->cConfFilePath = cConfFilePath;
 	if (pModule->pVisitCard->iSizeOfConfig > 0)
@@ -493,6 +489,7 @@ CairoDockModuleInstance *cairo_dock_instanciate_module (CairoDockModule *pModule
 */
 static void _cairo_dock_free_module_instance (CairoDockModuleInstance *pInstance)
 {
+	cairo_dock_notify_on_object (pInstance, NOTIFICATION_DESTROY, pInstance);
 	g_free (pInstance->cConfFilePath);
 	/*g_free (pInstance->pConfig);
 	g_free (pInstance->pData);*/
@@ -536,7 +533,7 @@ void cairo_dock_deinstanciate_module (CairoDockModuleInstance *pInstance)  // st
 	
 	pInstance->pModule->pInstancesList = g_list_remove (pInstance->pModule->pInstancesList, pInstance);
 	if (pInstance->pModule->pInstancesList == NULL)
-		cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_ACTIVATED, pInstance->pModule->pVisitCard->cModuleName, FALSE);
+		cairo_dock_notify_on_object (pInstance->pModule, NOTIFICATION_MODULE_ACTIVATED, pInstance->pModule->pVisitCard->cModuleName, FALSE);
 	
 	_cairo_dock_free_module_instance (pInstance);
 }
@@ -664,10 +661,7 @@ void cairo_dock_reload_module_instance (CairoDockModuleInstance *pInstance, gboo
 			g_key_file_free (pKeyFile);
 			pKeyFile = NULL;
 		}
-		pIcon->fWidth = pMinimalConfig->iDesiredIconWidth;  // requested size
-		pIcon->fHeight = pMinimalConfig->iDesiredIconHeight;
-		pIcon->iImageWidth = 0;
-		pIcon->iImageHeight = 0;
+		cairo_dock_icon_set_requested_display_size (pIcon, pMinimalConfig->iDesiredIconWidth, pMinimalConfig->iDesiredIconHeight);
 		
 		// on insere l'icone dans le dock ou on met a jour celui-ci.
 		if (pNewDock != pCurrentDock)  // insert in its new dock.
@@ -827,18 +821,19 @@ void cairo_dock_activate_module (CairoDockModule *module, GError **erreur)
 		cairo_dock_instanciate_module (module, NULL);
 	}
 	
-	cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_ACTIVATED, module->pVisitCard->cModuleName, TRUE);
+	cairo_dock_notify_on_object (module, NOTIFICATION_MODULE_ACTIVATED, module->pVisitCard->cModuleName, TRUE);
 }
 
 void cairo_dock_deactivate_module (CairoDockModule *module)  // stop all instances of a module
 {
 	g_return_if_fail (module != NULL);
 	cd_debug ("%s (%s, %s)", __func__, module->pVisitCard->cModuleName, module->cConfFilePath);
-	g_list_foreach (module->pInstancesList, (GFunc) _cairo_dock_stop_module_instance, NULL);
-	g_list_foreach (module->pInstancesList, (GFunc) _cairo_dock_free_module_instance, NULL);
-	g_list_free (module->pInstancesList);
-	module->pInstancesList = NULL;
-	cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_ACTIVATED, module->pVisitCard->cModuleName, FALSE);
+	GList *pInstances = module->pInstancesList;
+	module->pInstancesList = NULL;  // set to NULL already so that notifications don't get fooled.
+	g_list_foreach (pInstances, (GFunc) _cairo_dock_stop_module_instance, NULL);
+	g_list_foreach (pInstances, (GFunc) _cairo_dock_free_module_instance, NULL);
+	g_list_free (pInstances);
+	cairo_dock_notify_on_object (module, NOTIFICATION_MODULE_ACTIVATED, module->pVisitCard->cModuleName, FALSE);
 }
 
 void cairo_dock_reload_module (CairoDockModule *pModule, gboolean bReloadAppletConf)
