@@ -27,14 +27,15 @@
 #include <cairo.h>
 
 #include "gldi-config.h"
+#include "gldi-module-config.h"
 #include "cairo-dock-notifications.h"
 #include "cairo-dock-dock-facility.h"  // cairo_dock_update_dock_size
 #include "cairo-dock-dock-manager.h"
-#include "cairo-dock-file-manager.h"  // cairo_dock_copy_file
+#include "cairo-dock-themes-manager.h"  // cairo_dock_add_conf_file
 #include "cairo-dock-keyfile-utilities.h"  // cairo_dock_conf_file_needs_update
 #include "cairo-dock-log.h"
 #include "cairo-dock-applet-manager.h"
-#include "cairo-dock-X-manager.h"  // g_desktopGeometry
+#include "cairo-dock-X-manager.h"  // gldi_get_desktop_width
 #include "cairo-dock-desklet-manager.h"
 #include "cairo-dock-animations.h"
 #include "cairo-dock-config.h"
@@ -51,7 +52,6 @@ CairoDockModuleInstance *g_pCurrentModule = NULL;  // only used to trace a possi
 
 // dependancies
 extern gchar *g_cConfFile;
-extern CairoDockDesktopGeometry g_desktopGeometry;
 
 // private
 static GHashTable *s_hModuleTable = NULL;
@@ -324,8 +324,7 @@ void cairo_dock_activate_module_and_load (const gchar *cModuleName)
 		pInstance = pElement->data;
 		if (pInstance->pDock)
 		{
-			cairo_dock_trigger_update_dock_size (pInstance->pDock);
-			///gtk_widget_queue_draw (pInstance->pDock->container.pWidget);
+			///cairo_dock_trigger_update_dock_size (pInstance->pDock);
 		}
 	}
 	
@@ -391,10 +390,11 @@ void cairo_dock_remove_module_instance (CairoDockModuleInstance *pInstance)
 	
 	//\_________________ we remove the .conf file for this instance.
 	cd_debug ("We remove %s", pInstance->cConfFilePath);
-	g_remove (pInstance->cConfFilePath);
+	cairo_dock_delete_conf_file (pInstance->cConfFilePath);
 	
-	//\_________________ We also remove the cConfFilePath (=> this conf file no longer exist during the stop during the stop)
+	//\_________________ We also remove the cConfFilePath (=> this conf file no longer exist during the 'stop' callback)
 	g_free (pInstance->cConfFilePath);
+	pInstance->cConfFilePath = NULL;
 	cairo_dock_deactivate_module_instance_and_unload (pInstance);  // pInstance n'est plus.
 }
 
@@ -426,21 +426,18 @@ gchar *cairo_dock_add_module_conf_file (CairoDockModule *pModule)
 		GList *last = g_list_last (pModule->pInstancesList);
 		pFirstInstance = last->data;  // instances are prepended.
 		
-		cairo_dock_copy_file (pFirstInstance->cConfFilePath, cConfFilePath);
-		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pFirstInstance->cConfFilePath, cConfFilePath);
-		int r = system (cCommand);
-		g_free (cCommand);*/
+		cairo_dock_add_conf_file (pFirstInstance->cConfFilePath, cConfFilePath);
 		
 		if (pFirstInstance->pDesklet)  // prevent desklets from overlapping.
 		{
 			int iX2, iX = pFirstInstance->pContainer->iWindowPositionX;
 			int iWidth = pFirstInstance->pContainer->iWidth;
-			if (iX + iWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2)  // desklet on the left, we place the new one on its right.
+			if (iX + iWidth/2 <= gldi_get_desktop_width()/2)  // desklet on the left, we place the new one on its right.
 				iX2 = iX + iWidth;
 			else  // desklet on the right, we place the new one on its left.
 				iX2 = iX - iWidth;
 			
-			int iRelativePositionX = (iX2 + iWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2 ? iX2 : iX2 - g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
+			int iRelativePositionX = (iX2 + iWidth/2 <= gldi_get_desktop_width()/2 ? iX2 : iX2 - gldi_get_desktop_width());
 			cairo_dock_update_conf_file (cConfFilePath,
 				G_TYPE_INT, "Desklet", "x position", iRelativePositionX,
 				G_TYPE_BOOLEAN, "Desklet", "locked", FALSE,  // we'll probably want to move it
@@ -450,10 +447,7 @@ gchar *cairo_dock_add_module_conf_file (CairoDockModule *pModule)
 	}
 	else  // no instance yet, just copy the default conf file.
 	{
-		cairo_dock_copy_file (pModule->cConfFilePath, cConfFilePath);
-		/**gchar *cCommand = g_strdup_printf ("cp \"%s\" \"%s\"", pModule->cConfFilePath, cConfFilePath);
-		int r = system (cCommand);
-		g_free (cCommand);*/
+		cairo_dock_add_conf_file (pModule->cConfFilePath, cConfFilePath);
 	}
 	
 	g_free (cUserDataDirPath);
@@ -497,7 +491,7 @@ void cairo_dock_detach_module_instance (CairoDockModuleInstance *pInstance)
 		if (pInstance->pDesklet)  // on a bien detache l'applet.
 			cairo_dock_zoom_out_desklet (pInstance->pDesklet);
 		//\__________________ On met a jour le panneau de conf s'il etait ouvert sur cette applet.
-		cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_INSTANCE_DETACHED, pInstance, !bIsDetached);
+		cairo_dock_notify_on_object (pInstance, NOTIFICATION_MODULE_INSTANCE_DETACHED, pInstance, !bIsDetached);
 	}
 }
 
@@ -515,9 +509,6 @@ void cairo_dock_detach_module_instance_at_position (CairoDockModuleInstance *pIn
 	int iDeskletPositionX = iCenterX - iDeskletWidth/2;
 	int iDeskletPositionY = iCenterY - iDeskletHeight/2;
 	
-	// int iRelativePositionX = (iDeskletPositionX + iDeskletWidth/2 <= g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionX : iDeskletPositionX - g_desktopGeometry.iXScreenWidth[CAIRO_DOCK_HORIZONTAL]);
-	// int iRelativePositionY = (iDeskletPositionY + iDeskletHeight/2 <= g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]/2 ? iDeskletPositionY : iDeskletPositionY - g_desktopGeometry.iXScreenHeight[CAIRO_DOCK_HORIZONTAL]);
-	
 	//\__________________ update the conf file of the applet.
 	g_key_file_set_double (pKeyFile, "Desklet", "x position", iDeskletPositionX);
 	g_key_file_set_double (pKeyFile, "Desklet", "y position", iDeskletPositionY);
@@ -530,7 +521,7 @@ void cairo_dock_detach_module_instance_at_position (CairoDockModuleInstance *pIn
 	g_key_file_free (pKeyFile);
 	
 	//\__________________ On met a jour le panneau de conf s'il etait ouvert sur cette applet.
-	cairo_dock_notify_on_object (&myModulesMgr, NOTIFICATION_MODULE_INSTANCE_DETACHED, pInstance, TRUE);  // inutile de notifier du changement de taille, le configure-event du desklet s'en chargera.
+	cairo_dock_notify_on_object (pInstance, NOTIFICATION_MODULE_INSTANCE_DETACHED, pInstance, TRUE);  // inutile de notifier du changement de taille, le configure-event du desklet s'en chargera.
 	
 	//\__________________ On detache l'applet.
 	cairo_dock_reload_module_instance (pInstance, TRUE);
