@@ -175,6 +175,20 @@ is_hyper (const gchar *string)
 	  (string[6] == '>'));
 }
 
+static inline gboolean
+is_primary (const gchar *string)
+{
+	return ((string[0] == '<') &&
+		(string[1] == 'p' || string[1] == 'P') &&
+		(string[2] == 'r' || string[2] == 'R') &&
+		(string[3] == 'i' || string[3] == 'I') &&
+		(string[4] == 'm' || string[4] == 'M') &&
+		(string[5] == 'a' || string[5] == 'A') &&
+		(string[6] == 'r' || string[6] == 'R') &&
+		(string[7] == 'y' || string[7] == 'Y') &&
+		(string[8] == '>'));
+}
+
 /**
  * Parses a string representing a virtual accelerator. The format
  * looks like "&lt;Control&gt;a" or "&lt;Shift&gt;&lt;Alt&gt;F1" or
@@ -295,6 +309,12 @@ egg_accelerator_parse_virtual (const gchar            *accelerator,
 	      len -= 7;
 	      mods |= EGG_VIRTUAL_SUPER_MASK;
 	    }
+          else if (len >= 9 && is_primary (accelerator))
+	    {
+	      accelerator += 9;
+	      len -= 9;
+	      mods |= EGG_VIRTUAL_CONTROL_MASK;
+	    }
 	  else
 	    {
 	      gchar last_ch;
@@ -659,15 +679,8 @@ int *egg_keystring_to_keysyms (const gchar *accelerator, int *iNbKeys)
 	gint *pKeySyms = g_new0 (int, iNbKeyMax);
 	const gchar *cKeyName;
 	
-	guint keyval;
-	GdkModifierType mods;
 	gint len;
-	gboolean bad_keyval;
 	
-	bad_keyval = FALSE;
-	
-	keyval = 0;
-	mods = 0;
 	len = strlen (accelerator);
 	while (len)
 		{
